@@ -4,7 +4,7 @@ ad_page_contract {
 
     @author Bryan Quinn (bquinn@arsdigita.com)
     @creation-date Mon Oct  9 00:15:52 2000
-    @cvs-id $Id: packages-install-3.tcl,v 1.14 2008/07/29 22:04:14 emmar Exp $
+    @cvs-id $Id: packages-install-3.tcl,v 1.14.8.1 2013/08/27 11:44:43 gustafn Exp $
 } {
 
 }
@@ -67,7 +67,9 @@ foreach pkg_info $pkg_install_list {
 	    incr file_count
 	}
 
-        if { [empty_string_p $version(auto-mount)] && [string equal $version(package.type) apm_application] } {
+        if { $version(auto-mount) eq "" 
+	     && $version(package.type) eq "apm_application" 
+	   } {
             set mount_html "<input type=\"checkbox\" name=\"mount_p\" value=\"$version(package.key)\" checked> Mount package under the main site at path <input type=\"text\" name=\"mount_path.$version(package.key)\" value=\"$version(package.key)\">"
         } else {
             set mount_html ""
