@@ -3,7 +3,7 @@ ad_page_contract {
 
     @author Peter Marklund (peter@collaboraid.biz)
     @creation-date 8 October 2002
-    @cvs-id $Id: version-i18n-process-2.tcl,v 1.16 2008/07/29 19:22:23 emmar Exp $  
+    @cvs-id $Id: version-i18n-process-2.tcl,v 1.16.8.1 2013/08/27 11:44:43 gustafn Exp $  
 } {
     version_id:integer,notnull    
     {files:multiple,notnull}
@@ -32,7 +32,7 @@ if { [info exists skip_button] } {
 set message_key_list [list]
 for { set counter 1 } { $counter <= $number_of_keys } { incr counter } {
     if { [info exists replace_p($counter)] } {
-        if { [exists_and_not_null message_keys($counter)] } {
+        if { ([info exists message_keys($counter)] && $message_keys($counter) ne "") } {
             lappend message_key_list $message_keys($counter)
         } else {
             ad_return_complaint 1 "<li>Message key number $counter is empty. Cannot replace text with empty key</li>"
