@@ -1,7 +1,7 @@
 ad_page_contract {
     Sends email confirmation to user after they've been created
 
-    @cvs-id $Id: user-add-3.tcl,v 1.6 2009/07/12 01:08:22 donb Exp $
+    @cvs-id $Id: user-add-3.tcl,v 1.6.6.1 2013/08/27 11:44:44 gustafn Exp $
 } -query {
     email
     message
@@ -24,7 +24,7 @@ set export_vars [export_url_vars user_id]
 set admin_email [db_string get_admin_email {}]
 set subject "You have been added as a user to [ad_system_name] at [ad_url]"
 
-if [catch {acs_mail_lite::send -send_immediately -to_addr $email -from_addr $admin_email -subject $subject -body $message} errmsg] {
+if {[catch {acs_mail_lite::send -send_immediately -to_addr $email -from_addr $admin_email -subject $subject -body $message} errmsg]} {
     ad_return_error "Mail Failed" "<p>The system was unable to send email.  Please notify the user personally.  This problem is probably caused by a misconfiguration of your email system.  Here is the error:</p>
 <div><code>
 [ad_quotehtml $errmsg]
