@@ -7,11 +7,12 @@ ad_page_contract {
         <code>procs</code> or <code>content</code>.
     @author Jon Salz (jsalz@mit.edu)
     @creation-date 3 Jul 2000
-    @cvs-id $Id: package-view.tcl,v 1.6 2005/02/26 17:52:20 jeffd Exp $
+    @cvs-id $Id: package-view.tcl,v 1.7 2013/05/16 08:41:46 gustafn Exp $
 } {
     version_id
     { public_p "" }
     { kind "procs_files" }
+    { about_package_key ""}
 } -properties {
     title:onevalue
     context:onevalue
@@ -55,7 +56,7 @@ set context [list $title]
 set dimensional_slider "[ad_dimensional \
         $dimensional_list \
         "" \
-        [ad_tcl_vars_to_ns_set version_id kind public_p]]"
+        [ad_tcl_vars_to_ns_set version_id kind public_p about_package_key]]"
 
 switch $kind {
     procs_files {
