@@ -3,7 +3,7 @@ ad_library {
     
     @creation-date 2003-09-05
     @author Lars Pind (lars@collaboraid.biz)
-    @cvs-id $Id: sync-procs.tcl,v 1.34 2009/07/12 01:08:23 donb Exp $
+    @cvs-id $Id: sync-procs.tcl,v 1.34.6.1 2013/08/25 20:00:12 gustafn Exp $
 }
 
 namespace eval auth {}
@@ -518,7 +518,9 @@ ad_proc -public auth::sync::purge_jobs {
                           -default 0]
     }
     
-    validate_integer num_days $num_days
+    if {![string is integer -strict $num_days]} {
+	error "num_days ($num_days) has to be an integer"
+    }
 
     if { $num_days > 0 } { 
         db_dml purge_jobs {}
