@@ -16,7 +16,7 @@ ad_library {
     
     @author Peter Harper (peter.harper@open-msg.com)
     @creation-date 21 June 2001
-    @cvs-id $Id: aa-test-procs.tcl,v 1.38 2009/09/17 15:57:01 daveb Exp $
+    @cvs-id $Id: aa-test-procs.tcl,v 1.38.6.1 2013/08/27 11:50:27 gustafn Exp $
 }
 
 # LARS: We do this here, because if we do it in the -init file, then we cannot register 
@@ -942,7 +942,7 @@ ad_proc -public aa_run_with_teardown {
 
             aa_execute_rollback_tests
 
-            if { !\[empty_string_p \$errmsg\] && !\[string equal \$errmsg \"rollback tests\"\] } {
+            if { \$errmsg ne {} && \$errmsg ne \"rollback tests\"\ } {
                 global errorInfo
                 error \"\$errmsg \n\n \$errorInfo\"
             }
