@@ -3,7 +3,7 @@ ad_library {
 
     @author Peter Marklund
     @creation-date 31 March 2004
-    @cvs-id $Id: tclwebtest-procs.tcl,v 1.7 2007/05/14 20:30:18 donb Exp $
+    @cvs-id $Id: tclwebtest-procs.tcl,v 1.7.10.1 2013/08/27 11:50:27 gustafn Exp $
 }
 
 namespace eval twt {}
@@ -193,7 +193,7 @@ ad_proc twt::user::login { email password {username ""}}  {
     set response_url [tclwebtest::response url]
 
     if { ![string match "*${home_uri}*" $response_url] } {
-        if { [empty_string_p [cc_lookup_email_user $email]] } {
+        if { [cc_lookup_email_user $email] eq "" } {
             error "Failed to login user with email=\"$email\" and password=\"$password\". No user with such email in database."
         } else {
             ns_log Error "Failed to log in user with email=\"$email\" and password=\"$password\" eventhough email exists (password may be incorrect). response_body=[tclwebtest::response body]"
