@@ -4,7 +4,7 @@
 #
 # @creation-date 12 May 2000
 # @author Jon Salz [jsalz@arsdigita.com]
-# @cvs-id $Id: bootstrap.tcl,v 1.31 2011/04/18 16:59:30 donb Exp $
+# @cvs-id $Id: bootstrap.tcl,v 1.31.4.1 2013/08/23 10:08:48 gustafn Exp $
 
 
 # Remember the length of the error log file (so we can easily seek back to this
@@ -40,7 +40,7 @@ proc bootstrap_fatal_error { message { throw_error_p 1 } } {
     ns_log Error "$proc_name: Server startup failed: $message\n$errorInfo"
 
     # Define a filter procedure which displays the appropriate error message.
-    proc bootstrap_write_error { conn arg why } {
+    proc bootstrap_write_error { args } {
 	ns_returnerror 503 "Server startup failed: [nsv_get bootstrap_fatal_error .]"
 	return "filter_return"
     }
@@ -61,7 +61,7 @@ set errno [catch {
 
     # Load the special bootstrap tcl library.
 
-    set files [glob -nocomplain "$root_directory/packages/acs-bootstrap-installer/tcl/*-procs.tcl"]
+    set files [lsort [glob -nocomplain "$root_directory/packages/acs-bootstrap-installer/tcl/*-procs.tcl"]]
     if { [llength $files] == 0 } {
 	error "Unable to locate $root_directory/packages/acs-bootstrap-installer/tcl/*-procs.tcl."
     }
