@@ -276,8 +276,8 @@ proc install_handler { conn arg why } {
     }
 
     if { ![regexp {/([a-zA-Z0-9\-_]*)$} [ad_conn url] "" script] } {
-	ad_returnredirect "/"
-	return
+	ns_returnredirect "/"
+	return "filter_return"
     }
 
     if { $script eq "" } {
