@@ -11,7 +11,7 @@ ad_page_contract {
     @author Bryan Quinn (bquinn@arsdigita.com)
     @author Richard Li (richardl@arsdigita.com)
     @creation-date Mon Oct  9 15:19:31 2000
-    @cvs-id $Id: index.tcl,v 1.27 2009/01/17 12:17:12 miguelc Exp $
+    @cvs-id $Id: index.tcl,v 1.28 2013/03/30 21:30:16 gustafn Exp $
 } {
 
 }
@@ -172,7 +172,7 @@ if {![xml_support_ok xml_status_msg]} {
 
 # AOLserver must support the "fancy" ADP parser.
 set adp_support [ns_config "ns/server/[ns_info server]/adp" DefaultParser]
-if {$adp_support ne "fancy"  } {
+if {$adp_support ne "fancy" && [ns_info name] ne "NaviServer"} {
     append errors "<li><p><strong>The fancy ADP parser is not enabled.  This is required to support 
 the OpenACS Templating System.  Without this templating system, none of the OpenACS pages installed by default
 will display.  Please add the following to your AOLserver configuration file (usually in 
