@@ -154,6 +154,10 @@ proc ad_proc args {
         return -code error "Switch -warn can be provided to ad_proc only if -deprecated is also provided"
     }
 
+    if { $deprecated_p } {
+	set warn_p 1
+    }
+
     if { $impl ne "" && $callback eq "" } {
         return -code error "A callback contract name must be specified with -callback when defining an implementation with -impl"
     }
@@ -429,11 +433,11 @@ proc ad_proc args {
 
     set log_code ""
     if { $warn_p } {
-        set log_code "ns_log Debug \"Deprecated proc $proc_name used:\\n\[ad_get_tcl_call_stack\]\"\n"
+        set log_code "ns_log Notice \"Deprecated proc $proc_name used:\\n\[ad_get_tcl_call_stack\]\"\n"
     }
 
     if { $callback ne "" && $impl ne "" } {
-        if { [llength [info procs "::callback::${callback}::contract__arg_parser"]] == 0 } {
+        if { [info commands "::callback::${callback}::contract__arg_parser"] eq "" } {
             # We create a dummy arg parser for the contract in case
             # the contract hasn't been defined yet.  We need this
             # because the implementation doesn't tell us what the
@@ -783,7 +787,7 @@ ad_proc -public callback {
     # arg validation -- ::callback::${callback}::contract is an 
     # empty function that only runs the ad_proc generated arg parser.
 
-    if {[llength [info proc ::callback::${callback}::contract]] != 1} {
+    if {[info commands ::callback::${callback}::contract] eq ""} {
         error "Undefined callback $callback"
     }
     eval ::callback::${callback}::contract $args
@@ -791,8 +795,7 @@ ad_proc -public callback {
     set returns {}
 
     set base ::callback::${callback}::impl
-    foreach procname [lsort [info procs ${base}::$impl]] {
-
+    foreach procname [lsort [info commands ${base}::$impl]] {
         set c [catch {::uplevel 1 $procname $args} ret]
         switch -exact $c {
             0 { # code ok
@@ -850,7 +853,7 @@ ad_library {
 
     @creation-date 7 Jun 2000
     @author Jon Salz (jsalz@mit.edu)
-    @cvs-id $Id: 00-proc-procs.tcl,v 1.39 2010/10/30 21:43:01 gustafn Exp $
+    @cvs-id $Id: 00-proc-procs.tcl,v 1.41.2.3 2013/08/25 19:54:34 gustafn Exp $
 }
 
 ad_proc -public empty_string_p {query_string} {
