@@ -4,7 +4,7 @@ ad_library {
 
     @creation-date 26 May 2000
     @author Jon Salz [jsalz@arsdigita.com]
-    @cvs-id $Id: 30-apm-load-procs.tcl,v 1.34 2009/02/13 20:28:08 jeffd Exp $
+    @cvs-id $Id: 30-apm-load-procs.tcl,v 1.41.2.1 2013/08/24 15:27:25 gustafn Exp $
 }
 
 # FIXME: Peter M - This file cannot be watched with the APM as it re-initializes 
@@ -82,7 +82,7 @@ ad_proc -public apm_guess_file_type { package_key path } {
 
 } {
     set components [split $path "/"]
-    set dirs_in_pageroot [llength [split [ns_info pageroot] "/"]]	   ;# See comments by RBM
+    set dirs_in_pageroot [llength [split $::acs::pageroot "/"]]	   ;# See comments by RBM
 
     # Fix to cope with both full and relative paths
     if { [string index $path 0] eq "/"} {                          
@@ -166,6 +166,8 @@ ad_proc -public apm_guess_file_type { package_key path } {
 }
 
 ad_proc -public apm_get_package_files {
+   {-include_data_model_files:boolean}
+   {-all:boolean}
    {-all_db_types:boolean}
    {-package_key:required}
    {-package_path {}}
@@ -201,7 +203,12 @@ ad_proc -public apm_get_package_files {
         set package_path [acs_package_root_dir $package_key]
     }
 
-    set files [lsort [ad_find_all_files -check_file_func apm_include_file_p $package_path]]
+    if {$all_p} {
+      set file_function ""
+    } else {
+      set file_function [expr {$include_data_model_files_p ? "apm_include_data_model_file_p" : "apm_include_file_p"}]
+    }
+    set files [lsort [ad_find_all_files -check_file_func $file_function $package_path]]
     # We don't assume db_type proc is defined yet
     set system_db_type [nsv_get ad_database_type .]
 
@@ -444,7 +451,7 @@ ad_proc -private apm_bootstrap_load_libraries {
 
         # Call db_release_unused_handles, only if the library defining it
         # (10-database-procs.tcl) has been sourced yet.
-        if { [llength [info procs db_release_unused_handles]] != 0 } {
+        if { [info commands db_release_unused_handles] ne ""} {
             db_release_unused_handles
         }
     }
@@ -508,19 +515,48 @@ ad_proc -private apm_install_xml_file_path {} {
     return "[acs_root_dir]/install.xml"
 }
 
-ad_proc -private apm_ignore_file_p { path } {
+ad_proc -private apm_ignore_file_p { 
+    {-data_model_files:boolean}
+    path 
+} {
 
     Return 1 if $path should, in general, be ignored for package operations.
     Currently, a file is ignored if it is a backup file or a CVS directory.
 
 } {
-    set tail [file tail $path]
-    if { [apm_backup_file_p $tail] } {
-	return 1
+    if {[file isdirectory $path]} {
+	#
+	# ignored directories
+	#
+	set parts [file split $path]
+	if {[lindex $parts end] eq "resources" && [lindex $parts end-1] eq "www"} {
+	    return 1
+	}
+
+    set dir_list {CVS .git catalog}
+    if {!$data_model_files_p} {
+        lappend dir_list "upgrade"
     }
-    if {$tail eq "CVS"} {
-	return 1
+    
+	if {[lindex $parts end] in $dir_list} {
+	    return 1
+	}
     }
+    #
+    # ignored extensions
+    #
+    set extension_list {.html .gif .png .jpg .ico .pdf .js .css .xsl .tgz .zip .gz .java}
+    if {!$data_model_files_p} {
+        lappend extension_list ".sql"
+    }
+    if {[file extension $path] in $extension_list} {
+        return 1 
+    }
+
+    if { [apm_backup_file_p [file tail $path]] } {
+        return 1
+    }
+
     return 0
 }
 
@@ -537,13 +573,24 @@ ad_proc -private apm_backup_file_p { path } {
     </ul>
 
 } {
-    return [regexp {(\.old|\.bak|~)$|^#|^bak([^a-zA-Z]|$)} [file tail $path]]
+    return [regexp {(\.old|\.bak|~)$|^#|^bak$|^bak([^a-zA-Z]+)} $path]
 }
 
-ad_proc -private apm_include_file_p { filename } {    
+ad_proc -private apm_include_data_model_file_p { filename } {    
     Check if the APM should consider a file found by ad_find_all_files.
     Files for which apm_ignore_file_p returns true will be ignored.
     Backup files are ignored.
 } {
+    #ns_log notice "apm_include_file_p <$filename> => [apm_ignore_file_p -data_model_files $filename]"
+    return [expr {![apm_ignore_file_p -data_model_files $filename]}] 
+}
+
+
+ad_proc -private apm_include_file_p { filename } {    
+    Check if the APM should consider a file found by ad_find_all_files.
+    Files for which apm_ignore_file_p returns true will be ignored.
+    Backup files and sql scripts (including the ones in upgrade directory) are ignored.
+} {
+    #ns_log notice "apm_include_file_p <$filename> => [apm_ignore_file_p $filename]"
     return [expr {![apm_ignore_file_p $filename]}] 
 }
