@@ -16,24 +16,37 @@
 # The following code allows ad_proc to be used
 # here (a local workalike is declared if absent).
 # added 2002-09-11 Jeff Davis (davis@xarg.net)
-if {! [string equal {} [info procs ad_library]]} { 
+if {[info commands ad_library] ne "" } { 
     ad_library {
         Query Dispatching for multi-RDBMS capability
 
         @author Ben Adida (ben@openforce.net)
         @author Bart Teeuwisse (bart.teeuwisse@thecodemill.biz)
-	@cvs-id $Id: 40-db-query-dispatcher-procs.tcl,v 1.36 2003/11/27 14:06:03 peterm Exp $
+	@cvs-id $Id: 40-db-query-dispatcher-procs.tcl,v 1.42.2.1 2013/08/27 11:01:48 gustafn Exp $
     } 
 }
 
-if { ! [string equal {} [info procs ad_proc]] } {
+if { [info commands ad_proc] ne ""} {
     set remove_ad_proc_p 0
 } else { 
     set remove_ad_proc_p 1
-    proc ad_proc {name arglist args} { 
+    proc ad_proc {args} { 
+        # we have to eat flags and then define the proc.
+        set count 0
+        foreach arg $args {
+            if {![string match {-*} $arg]} {
+                break
+            }
+            incr count
+        }
+        set name [lindex $args $count]
+        incr count
+        set arglist [lindex $args $count]
+        incr count
+        set args [lrange $args $count end]
         # args can be {docs body} {body} {docs -} 
         # make sure it is non empty and does not end in -
-        if {[llength $args] && ![string equal [lindex $args end] "-"]} { 
+        if {[llength $args] && [lindex $args end] ne "-" } { 
             proc $name $arglist [lindex $args end]
         }
     }
@@ -44,13 +57,13 @@ if { ! [string equal {} [info procs ad_proc]] } {
 # The RDBMS Data Abstraction
 ##################################
 
-ad_proc db_rdbms_create {type version} {
+ad_proc -public db_rdbms_create {type version} {
     @return rdbms descriptor
 } { 
     return [list $type $version]
 }
 
-ad_proc db_rdbms_get_type {rdbms} {
+ad_proc -public db_rdbms_get_type {rdbms} {
     @param rdbms descriptor constructed by db_rdbms_create
 
     @return rdbms name
@@ -58,7 +71,7 @@ ad_proc db_rdbms_get_type {rdbms} {
     return [lindex $rdbms 0]
 }
 
-ad_proc db_rdbms_get_version {rdbms} {
+ad_proc -public db_rdbms_get_version {rdbms} {
     @param rdbms descriptor constructed by db_rdbms_create
 
     @return version identifier
@@ -66,36 +79,37 @@ ad_proc db_rdbms_get_version {rdbms} {
     return [lindex $rdbms 1]
 }
 
-ad_proc db_rdbms_compatible_p {rdbms_test rdbms_pattern} {
+ad_proc -public db_rdbms_compatible_p {rdbms_test rdbms_pattern} {
     @return 0 if test incompatible with pattern, 1 if miscible
 } { 
-    db_qd_log QDDebug "The RDBMS_TEST is [db_rdbms_get_type $rdbms_test] - [db_rdbms_get_version $rdbms_test]"
-    db_qd_log QDDebug "The RDBMS_PATTERN is [db_rdbms_get_type $rdbms_pattern] - [db_rdbms_get_version $rdbms_pattern]"
+    # db_qd_log QDDebug "The RDBMS_TEST is [db_rdbms_get_type $rdbms_test] - [db_rdbms_get_version $rdbms_test]"
+    # db_qd_log QDDebug "The RDBMS_PATTERN is [db_rdbms_get_type $rdbms_pattern] - [db_rdbms_get_version $rdbms_pattern]"
 
     # If the pattern is for all RDBMS, then yeah, compatible
-    if {[empty_string_p [db_rdbms_get_type $rdbms_test]]} {
+    if {[db_rdbms_get_type $rdbms_test] eq ""} {
 	return 1
     }
 
     # If the RDBMS types are not the same, we have a problem
     if {[db_rdbms_get_type $rdbms_test] != [db_rdbms_get_type $rdbms_pattern]} {
-	db_qd_log QDDebug "compatibility - RDBMS types are different!"
+	# db_qd_log QDDebug "compatibility - RDBMS types are different!"
 	return 0
     }
 
     # If the pattern has no version
-    if {[empty_string_p [db_rdbms_get_version $rdbms_pattern]]} {
+    if {[db_rdbms_get_version $rdbms_pattern] eq ""} {
 	return 1
     }
 
     # If the query being tested was written for a version that is older than 
     # the current RDBMS then we have compatibility. Otherwise we don't.
-    if {[db_rdbms_get_version $rdbms_test] <= [db_rdbms_get_version $rdbms_pattern]} {
-	return 1
-    }
-
-    db_qd_log QDDebug "compatibility - version numbers are bad!"
-    return 0
+    foreach t [split [db_rdbms_get_version $rdbms_test   ] "\."] \
+            p [split [db_rdbms_get_version $rdbms_pattern] "\."] {
+                if {$t != $p} {return [expr {$t < $p}]}
+            }
+    
+    # Same version (though not strictly "older") is OK
+    return 1
 }
 
 
@@ -107,7 +121,7 @@ ad_proc db_rdbms_compatible_p {rdbms_test rdbms_pattern} {
 
 
 
-ad_proc db_fullquery_create {queryname querytext bind_vars_lst query_type rdbms load_location} {
+ad_proc -public db_fullquery_create {queryname querytext bind_vars_lst query_type rdbms load_location} {
     FullQuery Data Abstraction Constructor
 } { 
     return [list $queryname $querytext $bind_vars_lst $query_type $rdbms $load_location]
@@ -115,7 +129,7 @@ ad_proc db_fullquery_create {queryname querytext bind_vars_lst query_type rdbms
 
 # The Accessor procs
 
-ad_proc db_fullquery_get_name {fullquery} {
+ad_proc -public db_fullquery_get_name {fullquery} {
     Accessor for fullquery data abstraction
     @param fullquery datastructure constructed by db_fullquery_create 
     @return name
@@ -123,7 +137,7 @@ ad_proc db_fullquery_get_name {fullquery} {
     return [lindex $fullquery 0]
 }
 
-ad_proc db_fullquery_get_querytext {fullquery} {
+ad_proc -public db_fullquery_get_querytext {fullquery} {
     Accessor for fullquery data abstraction
     @param fullquery datastructure constructed by db_fullquery_create 
     @return query text
@@ -131,7 +145,7 @@ ad_proc db_fullquery_get_querytext {fullquery} {
     return [lindex $fullquery 1]
 }
 
-ad_proc db_fullquery_get_bind_vars {fullquery} {
+ad_proc -public db_fullquery_get_bind_vars {fullquery} {
     Accessor for fullquery data abstraction
     @param fullquery datastructure constructed by db_fullquery_create 
     @return bind vars
@@ -139,7 +153,7 @@ ad_proc db_fullquery_get_bind_vars {fullquery} {
     return [lindex $fullquery 2]
 }
 
-ad_proc db_fullquery_get_query_type {fullquery} {
+ad_proc -public db_fullquery_get_query_type {fullquery} {
     Accessor for fullquery data abstraction
     @param fullquery datastructure constructed by db_fullquery_create 
     @return query type
@@ -147,7 +161,7 @@ ad_proc db_fullquery_get_query_type {fullquery} {
     return [lindex $fullquery 3]
 }
 
-ad_proc db_fullquery_get_rdbms {fullquery} {
+ad_proc -public db_fullquery_get_rdbms {fullquery} {
     Accessor for fullquery data abstraction
     @param fullquery datastructure constructed by db_fullquery_create 
     @return rdbms descriptor
@@ -155,7 +169,7 @@ ad_proc db_fullquery_get_rdbms {fullquery} {
     return [lindex $fullquery 4]
 }
 
-ad_proc db_fullquery_get_load_location {fullquery} {
+ad_proc -public db_fullquery_get_load_location {fullquery} {
     Accessor for fullquery data abstraction
     @param fullquery datastructure constructed by db_fullquery_create 
     @return load location 
@@ -170,7 +184,7 @@ ad_proc db_fullquery_get_load_location {fullquery} {
 #
 ################################################
 
-ad_proc db_qd_pick_most_specific_query {rdbms query_1 query_2} {
+ad_proc -public db_qd_pick_most_specific_query {rdbms query_1 query_2} {
     For now, we're going to say that versions are numbers and that
     there is always backwards compatibility.
 } {
@@ -180,11 +194,11 @@ ad_proc db_qd_pick_most_specific_query {rdbms query_1 query_2} {
     # We ASSUME that both queries are at least compatible.
     # Otherwise this is a stupid exercise
 
-    if {[empty_string_p [db_rdbms_get_version $rdbms_1]]} {
+    if {[db_rdbms_get_version $rdbms_1] eq ""} {
 	return $query_2
     }
 
-    if {[empty_string_p [db_rdbms_get_version $rdbms_2]]} {
+    if {[db_rdbms_get_version $rdbms_2] eq ""} {
 	return $query_1
     }
 
@@ -203,7 +217,7 @@ ad_proc db_qd_pick_most_specific_query {rdbms query_1 query_2} {
 #
 ################################################
 
-ad_proc db_qd_load_query_file {file_path} {
+ad_proc -public db_qd_load_query_file {file_path} {
     A procedure that is called from the outside world (APM) 
     to load a particular file
 } { 
@@ -214,7 +228,7 @@ ad_proc db_qd_load_query_file {file_path} {
 }
 
 
-ad_proc db_qd_get_fullname {local_name {added_stack_num 1}} {
+ad_proc -public db_qd_get_fullname {local_name {added_stack_num 1}} {
     Find the fully qualified name of the query
 } { 
     # We do a check to see if we already have a fullname.
@@ -228,14 +242,14 @@ ad_proc db_qd_get_fullname {local_name {added_stack_num 1}} {
     # We catch this in case we're being called from the top level
     # (eg. from bootstrap.tcl), in which case we return what we
     # were given
-    if { [catch {string trimleft [info level [expr "-1 - $added_stack_num"]] ::} proc_name] } {
+    if { [catch {string trimleft [info level [expr {-1 - $added_stack_num}]] ::} proc_name] } {
 	return $local_name
     }
 
     # If util_memoize, we have to go back up one in the stack
-    if {[lindex $proc_name 0] == "util_memoize"} {
-	db_qd_log QDDebug "util_memoize! going up one level"
-	set proc_name [info level [expr "-2 - $added_stack_num"]]
+    if {[lindex $proc_name 0] eq "util_memoize"} {
+	# db_qd_log QDDebug "util_memoize! going up one level"
+	set proc_name [info level [expr {-2 - $added_stack_num}]]
     }
 
     set list_of_source_procs {ns_sourceproc apm_source template::adp_parse template::frm_page_handler rp_handle_tcl_request}
@@ -247,14 +261,14 @@ ad_proc db_qd_get_fullname {local_name {added_stack_num 1}} {
 	# Means we are running inside an URL
 
 	# TEST
-	for {set i 0} {$i < 6} {incr i} {
-	    if {[catch {db_qd_log QDDebug "LEVEL=$i= [info level [expr "-1 - $i"]]"} errmsg]} {}
-	}
+	# for {set i 0} {$i < 6} {incr i} {
+        #   if {[catch {db_qd_log QDDebug "LEVEL=$i= [info level [expr {-1 - $i}]]"} errmsg]} {}
+        # }
 
 	# Check the ad_conn stuff
-	if {[ns_conn isconnected]} {
-	    if {[catch {db_qd_log QDDebug "the ad_conn file is [ad_conn file]"} errmsg]} {}
-	}
+	# if {[ns_conn isconnected]} {
+        #   if {[catch {db_qd_log QDDebug "the ad_conn file is [ad_conn file]"} errmsg]} {}
+        # }
 
 	# Now we do a check to see if this is a directly accessed URL or a 
         # sourced URL
@@ -267,13 +281,13 @@ ad_proc db_qd_get_fullname {local_name {added_stack_num 1}} {
         switch $proc_name {
 
             ns_sourceproc {
-                db_qd_log QDDebug "We are in a WWW page, woohoo!"
+                # db_qd_log QDDebug "We are in a WWW page, woohoo!"
                 set real_url_p 1
                 set url [ns_conn url]
             }
 
             rp_handle_tcl_request {
-                db_qd_log QDDebug "We are in a VUH page sourced by rp_handle_tcl_request, woohoo!"
+                # db_qd_log QDDebug "We are in a VUH page sourced by rp_handle_tcl_request, woohoo!"
                 set real_url_p 0
                 regsub {\.vuh} [ad_conn file] {} url
                 set url [ad_make_relative_path $url]
@@ -281,13 +295,13 @@ ad_proc db_qd_get_fullname {local_name {added_stack_num 1}} {
             }
 
             template::frm_page_handler {
-                db_qd_log QDDebug "We are in the template system's form page debugger!"
+                # db_qd_log QDDebug "We are in the template system's form page debugger!"
                 set real_url_p 1
                 regsub {\.frm} [ad_conn url] {} url
             }
 
             default {
-                db_qd_log QDDebug "We are in a WWW page sourced by apm_source, woohoo!"
+                # db_qd_log QDDebug "We are in a WWW page sourced by apm_source, woohoo!"
                 set real_url_p 0
                 set url [lindex $proc_name 1]
                 set url [ad_make_relative_path $url]
@@ -308,7 +322,7 @@ ad_proc db_qd_get_fullname {local_name {added_stack_num 1}} {
         set rest {}
 	regexp {^([^\.]*)(.*)} $url all package_key rest
 
-	db_qd_log QDDebug "package key is $package_key and rest is $rest"
+	# db_qd_log QDDebug "package key is $package_key and rest is $rest"
 
 	if {$real_url_p} {
 	    set full_name [db_qd_make_absolute_path "${package_key}.www${rest}." $local_name]
@@ -327,15 +341,14 @@ ad_proc db_qd_get_fullname {local_name {added_stack_num 1}} {
         # proc_name, so that the correct query can be looked up. 
         # (Openacs - DanW)
 
-        set calling_namespace [string range [uplevel [expr 1 + $added_stack_num] {namespace current}] 2 end]
-        db_qd_log QDDebug "calling namespace = $calling_namespace"
-
-        if {![string equal $calling_namespace ""] && 
-            ![regexp {::} $proc_name all]} {
+        set calling_namespace [string range [uplevel [expr {1 + $added_stack_num}] {namespace current}] 2 end]
+        # db_qd_log QDDebug "calling namespace = $calling_namespace"
 
+        if {$calling_namespace ne "" && 
+            ![string match *::* $proc_name]} {
             set proc_name ${calling_namespace}::${proc_name}
         }
-	db_qd_log QDDebug "proc_name is -$proc_name-"
+	# db_qd_log QDDebug "proc_name is -$proc_name-"
 
 	# We use the ad_proc construct!! 
 	# (woohoo, can't believe that was actually useful!)
@@ -344,14 +357,14 @@ ad_proc db_qd_get_fullname {local_name {added_stack_num 1}} {
 	# probably dealing with one of the bootstrap procs, and so we just
 	# return a bogus proc name
 	if {![nsv_exists api_proc_doc $proc_name]} {
-	    db_qd_log QDDebug "there is no documented proc with name $proc_name -- we used default SQL"
+	    ns_log warning "db_qd_get_fullname: there is no documented proc with name $proc_name returning [db_qd_null_path] (declare proc $proc_name with ad_proc to make it work with the query dispatcher"
 	    return [db_qd_null_path]
 	}
 
 	array set doc_elements [nsv_get api_proc_doc $proc_name]
 	set url $doc_elements(script)
 
-	db_qd_log QDDebug "tcl file is $url"
+	# db_qd_log QDDebug "tcl file is $url"
 
 	regsub {.tcl$} $url {} url
 
@@ -364,35 +377,33 @@ ad_proc db_qd_get_fullname {local_name {added_stack_num 1}} {
         set rest {}
 	regexp {^packages\.(.*)} $url all rest
 
-	db_qd_log QDDebug "TEMP - QD: proc_name is $proc_name"
-	db_qd_log QDDebug "TEMP - QD: local_name is $local_name"
+	# db_qd_log QDDebug "TEMP - QD: proc_name is $proc_name"
+	# db_qd_log QDDebug "TEMP - QD: local_name is $local_name"
 
 	# set full_name "acs.$rest.${proc_name}.${local_name}"
 	set full_name [db_qd_make_absolute_path "${rest}.${proc_name}." $local_name]
     }
 
-    db_qd_log QDDebug "generated fullname of $full_name"
+    # db_qd_log QDDebug "generated fullname of $full_name"
     
+    # The following block is apparently just for debugging
     # aks - making debug output actually useable
-    if {[llength $proc_name] > 1} {
-        
-        set proc_name_with_parameters "[lindex $proc_name 0] "
-        
-        set i 1
-        foreach parameter [lrange $proc_name  1 end] {
-            append proc_name_with_parameters "parameter$i: $parameter " 
-            incr i
-        }
-    } else {
-        set proc_name_with_parameters $proc_name
-    }
-
-    db_qd_log QDDebug "db_qd_get_fullname: following query in file: $url proc: $proc_name_with_parameters"
+    # if {[llength $proc_name] > 1} {
+    #     set proc_name_with_parameters "[lindex $proc_name 0] "
+    #     set i 1
+    #     foreach parameter [lrange $proc_name  1 end] {
+    #         append proc_name_with_parameters "parameter$i: $parameter " 
+    #         incr i
+    #     }
+    # } else {
+    #     set proc_name_with_parameters $proc_name
+    # }
+    # db_qd_log QDDebug "db_qd_get_fullname: following query in file: $url proc: $proc_name_with_parameters"
 
     return $full_name
 }
 
-ad_proc db_qd_fetch {fullquery_name {rdbms {}}} {
+ad_proc -public db_qd_fetch {fullquery_name {rdbms {}}} {
     Fetch a query with a given name
 
     This procedure returns the latest FullQuery data structure
@@ -404,16 +415,16 @@ ad_proc db_qd_fetch {fullquery_name {rdbms {}}} {
     return [db_qd_internal_get_cache $fullquery_name]
 }
 
-ad_proc db_qd_replace_sql {statement_name sql} {
+ad_proc -public db_qd_replace_sql {statement_name sql} {
     @return sql for statement_name (defaulting to sql if not found)
 } { 
     set fullquery [db_qd_fetch $statement_name]
 
-    if {![empty_string_p $fullquery]} {
+    if {$fullquery ne ""} {
 	set sql [db_fullquery_get_querytext $fullquery]
     } else {
 	db_qd_log Debug "NO FULLQUERY FOR $statement_name --> using default SQL"
-        if { [empty_string_p $sql] } {
+        if { $sql eq "" } {
             # The default SQL is empty, that implies a bug somewhere in the code.
             error "No fullquery for $statement_name and default SQL empty - query for statement missing"
         }
@@ -422,7 +433,7 @@ ad_proc db_qd_replace_sql {statement_name sql} {
     return $sql
 }
 
-ad_proc db_map {snippet_name} {
+ad_proc -public db_map {snippet_name} {
     fetch a query snippet.  used to provide db-specific query snippets when 
     porting highly dynamic queries.  (OpenACS - DanW)
 } { 
@@ -430,11 +441,11 @@ ad_proc db_map {snippet_name} {
     set fullquery [db_qd_fetch $fullname]
     set sql [db_fullquery_get_querytext $fullquery]
 
-    db_qd_log QDDebug "PARTIALQUERY FOR $fullname: $sql"
+    # db_qd_log QDDebug "PARTIALQUERY FOR $fullname: $sql"
     return [uplevel 1 [list subst -nobackslashes $sql]]
 }
 
-ad_proc db_fullquery_compatible_p {fullquery {rdbms {}}} {
+ad_proc -public db_fullquery_compatible_p {fullquery {rdbms {}}} {
     Check compatibility of a FullQuery against an RDBMS
 
     This procedure returns true or false. The RDBMS argument
@@ -460,7 +471,7 @@ ad_proc db_fullquery_compatible_p {fullquery {rdbms {}}} {
 ######################################################
 
 
-ad_proc db_qd_internal_load_queries {file_pointer file_tag} {
+ad_proc -private db_qd_internal_load_queries {file_pointer file_tag} {
     Load up a bunch of queries from a file pointer
 
     The file_tag parameter is for later flushing of a series
@@ -475,7 +486,7 @@ ad_proc db_qd_internal_load_queries {file_pointer file_tag} {
     # we're going to assume smaller files for now. Plus, this doesn't happen
     # often.
 
-    db_qd_log QDDebug "Loading $file_tag"
+    # db_qd_log QDDebug "Loading $file_tag"
 
     # Read entire contents
     set whole_file [read $file_pointer]
@@ -490,22 +501,22 @@ ad_proc db_qd_internal_load_queries {file_pointer file_tag} {
     set acs_file_path [ad_make_relative_path $file_tag]
     set queryname_root [db_qd_internal_get_queryname_root $acs_file_path]
 
-    db_qd_log QDDebug "db_qd_internal_load_queries: \n file: [lindex $parsing_state 4] \n default_rdbms: [lindex $parsing_state 3] \n queryname_root: $queryname_root"
+    # db_qd_log QDDebug "db_qd_internal_load_queries: \n file: [lindex $parsing_state 4] \n default_rdbms: [lindex $parsing_state 3] \n queryname_root: $queryname_root"
 
     while {1} {
 	set result [db_qd_internal_parse_one_query $parsing_state]
 	
-	db_qd_log QDDebug "one parse result -$result-"
+	# db_qd_log QDDebug "one parse result -$result-"
 
 	# If we get the empty string, we are done parsing
-	if {$result == ""} {
+	if {$result eq ""} {
 	    break
 	}
 
 	set one_query [lindex $result 0]
 	set parsing_state [lindex $result 1]
 
-	db_qd_log QDDebug "loaded one query - [db_fullquery_get_name $one_query]"
+	# db_qd_log QDDebug "loaded one query - [db_fullquery_get_name $one_query]"
 
 	# Relative Path for the Query
 	if {[db_qd_relative_path_p [db_fullquery_get_name $one_query]]} {
@@ -521,7 +532,7 @@ ad_proc db_qd_internal_load_queries {file_pointer file_tag} {
 
 	    set one_query $new_fullquery
 
-	    db_qd_log QDDebug "relative path, replaced name with $new_name"
+	    # db_qd_log QDDebug "relative path, replaced name with $new_name"
 	}
 
 	# Store the query
@@ -535,7 +546,7 @@ ad_proc db_qd_internal_load_queries {file_pointer file_tag} {
 
 
 
-ad_proc db_qd_internal_get_cache {fullquery_name} {
+ad_proc -private db_qd_internal_get_cache {fullquery_name} {
     Load from Cache
 } { 
     # If we have no record
@@ -546,13 +557,13 @@ ad_proc db_qd_internal_get_cache {fullquery_name} {
     set fullquery_array [nsv_get OACS_FULLQUERIES $fullquery_name]
 
     # If this isn't cached!
-    if {$fullquery_array == ""} {
+    if {$fullquery_array eq ""} {
 	# we need to do something
 	return ""
     }
 
     # See if we have the correct location for this query
-    db_qd_log QDDebug "query $fullquery_name from [db_fullquery_get_load_location $fullquery_array]"
+    # db_qd_log QDDebug "query $fullquery_name from [db_fullquery_get_load_location $fullquery_array]"
 
     # reload the fullquery
     set fullquery_array [nsv_get OACS_FULLQUERIES $fullquery_name]
@@ -561,7 +572,7 @@ ad_proc db_qd_internal_get_cache {fullquery_name} {
     return $fullquery_array
 }
 
-ad_proc db_qd_internal_store_cache {fullquery} {
+ad_proc -private db_qd_internal_store_cache {fullquery} {
     Store in Cache.  The load_location is the file where this query was found.
 } { 
 
@@ -570,12 +581,12 @@ ad_proc db_qd_internal_store_cache {fullquery} {
     if {![db_rdbms_compatible_p $rdbms [db_current_rdbms]]} {
         # The query isn't compatible, probably because of a too high version
         ns_log Warning "Query [db_fullquery_get_name $fullquery] has rdbms info $rdbms which is not compatible with system rdbms [db_current_rdbms]"
-        return
+        return 
     }
 
     set name [db_fullquery_get_name $fullquery]
 
-    db_qd_log QDDebug "Query $name is compatible! fullquery = $fullquery, name = $name"
+    # db_qd_log QDDebug "Query $name is compatible! fullquery = $fullquery, name = $name"
 
     # If we already have a query for that name, we need to
     # figure out which one is *most* compatible.
@@ -589,7 +600,7 @@ ad_proc db_qd_internal_store_cache {fullquery} {
 }
 
 
-ad_proc db_qd_internal_load_cache {file_path} {
+ad_proc -private db_qd_internal_load_cache {file_path} {
     Flush queries for a particular file path, and reload them
 } {
     # First we actually need to flush queries that are associated with that file tag
@@ -608,7 +619,7 @@ ad_proc db_qd_internal_load_cache {file_path} {
 ## NAMING
 ##
 
-ad_proc db_qd_internal_get_queryname_root {relative_path} {
+ad_proc -private db_qd_internal_get_queryname_root {relative_path} {
     @return relative path with trailing .
 } { 
     # remove the prepended "/packages/" string
@@ -638,7 +649,7 @@ ad_proc db_qd_internal_get_queryname_root {relative_path} {
 ## The architecture of this parsing scheme allows for streaming XML parsing
 ## in the future. But right now we keep things simple
 
-ad_proc db_qd_internal_parse_init {stuff_to_parse file_path} {
+ad_proc -private db_qd_internal_parse_init {stuff_to_parse file_path} {
     Initialize the parsing state
 } { 
     
@@ -652,8 +663,8 @@ ad_proc db_qd_internal_parse_init {stuff_to_parse file_path} {
     set root_node [xml_doc_get_first_node $parsed_doc]
 
     # Check that it's a queryset
-    if {[xml_node_get_name $root_node] != "queryset"} {
-	db_qd_log Error "OH OH, error, first node is [xml_node_get_name $root_node] and not 'queryset'"
+    if {[xml_node_get_name $root_node] ne "queryset"} {
+	# db_qd_log Error "OH OH, error, first node is [xml_node_get_name $root_node] and not 'queryset'"
         return ""
     }
 
@@ -661,18 +672,18 @@ ad_proc db_qd_internal_parse_init {stuff_to_parse file_path} {
     set rdbms_nodes [xml_node_get_children_by_name $root_node rdbms]
     if {[llength $rdbms_nodes] > 0} {
 	set default_rdbms [db_rdbms_parse_from_xml_node [lindex $rdbms_nodes 0]]
-	db_qd_log QDDebug "Detected DEFAULT RDBMS for whole queryset: $default_rdbms"
+	# db_qd_log QDDebug "Detected DEFAULT RDBMS for whole queryset: $default_rdbms"
     } else {
 	set default_rdbms ""
     }
 
     set parsed_stuff [xml_node_get_children_by_name $root_node fullquery]
-    db_qd_log QDDebug "db_qd_internal_parse_init extra info : index: $index; parsed_stuff: $parsed_stuff; parsed_doc: $parsed_doc;"
+    # db_qd_log QDDebug "db_qd_internal_parse_init extra info : index: $index; parsed_stuff: $parsed_stuff; parsed_doc: $parsed_doc;"
 
     return [list $index $parsed_stuff $parsed_doc $default_rdbms $file_path]
 }
 
-ad_proc db_qd_internal_parse_one_query {parsing_state} {
+ad_proc -private db_qd_internal_parse_one_query {parsing_state} {
     Parse one query using the query state
 } { 
     
@@ -694,7 +705,7 @@ ad_proc db_qd_internal_parse_one_query {parsing_state} {
 	# Clean up
 	xml_doc_free $parsed_doc
 
-	db_qd_log QDDebug "Cleaning up, done parsing"
+	# db_qd_log QDDebug "Cleaning up, done parsing"
 
 	# return nothing
 	return ""
@@ -719,13 +730,13 @@ ad_proc db_qd_internal_parse_one_query {parsing_state} {
 }
 
 
-ad_proc db_qd_internal_parse_one_query_from_xml_node {one_query_node {default_rdbms {}} {file_path {}}} {
+ad_proc -private db_qd_internal_parse_one_query_from_xml_node {one_query_node {default_rdbms {}} {file_path {}}} {
     Parse one query from an XML node
 } { 
-    db_qd_log QDDebug "parsing one query node in XML with name -[xml_node_get_name $one_query_node]-"
+    # db_qd_log QDDebug "parsing one query node in XML with name -[xml_node_get_name $one_query_node]-"
 
     # Check that this is a fullquery
-    if {[xml_node_get_name $one_query_node] != "fullquery"} {
+    if {[xml_node_get_name $one_query_node] ne "fullquery"} {
 	return ""
     }
     
@@ -739,7 +750,7 @@ ad_proc db_qd_internal_parse_one_query_from_xml_node {one_query_node {default_rd
     
     # If we have no RDBMS specified, use the default
     if {[llength $rdbms_nodes] == 0} {
-	db_qd_log QDDebug "Wow, Nelly, no RDBMS for this query, using default rdbms $default_rdbms"
+	# db_qd_log QDDebug "Wow, Nelly, no RDBMS for this query, using default rdbms $default_rdbms"
 	set rdbms $default_rdbms
     } else {
 	set rdbms_node [lindex $rdbms_nodes 0]
@@ -749,20 +760,20 @@ ad_proc db_qd_internal_parse_one_query_from_xml_node {one_query_node {default_rd
     return [db_fullquery_create $queryname $querytext [list] "" $rdbms $file_path]
 }
 
-ad_proc db_rdbms_parse_from_xml_node {rdbms_node} {
+ad_proc -private db_rdbms_parse_from_xml_node {rdbms_node} {
     Parse and RDBMS struct from an XML fragment node
 } { 
     # Check that it's RDBMS
-    if {[xml_node_get_name $rdbms_node] != "rdbms"} {
-	db_qd_log Debug "PARSER = BAD RDBMS NODE!"
-	return ""
+    if {[xml_node_get_name $rdbms_node] ne "rdbms"} {
+	db_qd_log Debug "db_rdbms_parse_from_xml_node: PARSER = BAD RDBMS NODE!"
+	return {}
     }
 
     # Get the type and version tags
     set type [xml_node_get_content [xml_node_get_first_child_by_name $rdbms_node type]]
     set version [xml_node_get_content [xml_node_get_first_child_by_name $rdbms_node version]]
 
-    db_qd_log QDDebug "PARSER = RDBMS parser - $type - $version"
+    # db_qd_log QDDebug "PARSER = RDBMS parser - $type - $version"
 
     return [db_rdbms_create $type $version]
 }
@@ -772,26 +783,26 @@ ad_proc db_rdbms_parse_from_xml_node {rdbms_node} {
 ## RELATIVE AND ABSOLUTE QUERY PATHS
 ##
 
-ad_proc db_qd_root_path {} {
+ad_proc -private db_qd_root_path {} {
     The token that indicates the root of all queries
 } { 
     return "dbqd."
 }
 
-ad_proc db_qd_null_path {} {
+ad_proc -private db_qd_null_path {} {
     The null path 
 } { 
     return "[db_qd_root_path].NULL"
 }
 
-ad_proc db_qd_relative_path_p {path} {
+ad_proc -private db_qd_relative_path_p {path} {
     Check if the path is relative
 } { 
     set root_path [db_qd_root_path]
     set root_path_length [string length $root_path]
 
     # Check if the path starts with the root
-    if {[string range $path 0 [expr "$root_path_length - 1"]] == $root_path} {
+    if {[string range $path 0 [expr {$root_path_length - 1}]] == $root_path} {
 	return 0
     } else {
 	return 1
@@ -799,7 +810,7 @@ ad_proc db_qd_relative_path_p {path} {
 }
 
 
-ad_proc db_qd_make_absolute_path {relative_root suffix} {
+ad_proc -private db_qd_make_absolute_path {relative_root suffix} {
     Make a path absolute
 } { 
     return "[db_qd_root_path]${relative_root}$suffix"
@@ -809,7 +820,7 @@ ad_proc db_qd_make_absolute_path {relative_root suffix} {
 ##
 ## Extra Utilities to Massage the system and Rub it in all the right ways
 ##
-ad_proc db_qd_internal_prepare_queryfile_content {file_content} {
+ad_proc -private db_qd_internal_prepare_queryfile_content {file_content} {
     
     set new_file_content ""
 
@@ -839,19 +850,19 @@ ad_proc db_qd_internal_prepare_queryfile_content {file_content} {
 	}
 
 	# append first chunk before the querytext including "<querytext>"
-	append new_file_content [string range $rest_of_file_content 0 [expr "$first_querytext_open + $querytext_open_len - 1"]]
+	append new_file_content [string range $rest_of_file_content 0 [expr {$first_querytext_open + $querytext_open_len - 1}]]
 
 	# append quoted querytext
-	append new_file_content [ns_quotehtml [string range $rest_of_file_content [expr "$first_querytext_open + $querytext_open_len"] [expr "$first_querytext_close - 1"]]]
+	append new_file_content [ns_quotehtml [string range $rest_of_file_content [expr {$first_querytext_open + $querytext_open_len}] [expr {$first_querytext_close - 1}]]]
 
 	# append close querytext
 	append new_file_content $querytext_close
 
 	# Set up the rest
-	set rest_of_file_content [string range $rest_of_file_content [expr "$first_querytext_close + $querytext_close_len"] end]
+	set rest_of_file_content [string range $rest_of_file_content [expr {$first_querytext_close + $querytext_close_len}] end]
     }
 
-    db_qd_log QDDebug "new massaged file content: \n $new_file_content \n"
+    # db_qd_log QDDebug "new massaged file content: \n $new_file_content \n"
 
     return $new_file_content
 }
@@ -861,11 +872,11 @@ ad_proc db_qd_internal_prepare_queryfile_content {file_content} {
 ## Logging
 ##
 
-ad_proc db_qd_log {level msg} {
+ad_proc -private db_qd_log {level msg} {
     Centralized DB QD logging
-    If you want to debug the DQ, change QDDebug below to Debug
-} { 
-    if {![string equal "QDDebug" $level]} {
+    If you want to debug the QD, change QDDebug below to Debug
+} {
+    if {"QDDebug" ne $level } {
         ns_log $level "$msg"
     }
 }
