@@ -12,23 +12,22 @@ ad_proc -public publish::get_page_root {} {
     Get the page root. All items will be published to the 
     filesystem with their URLs relative to this root.
     The page root is controlled by the PageRoot parameter in CMS.
-    A relative path is relative to [ns_info pageroot]
-    The default is [ns_info pageroot]
+    A relative path is relative to $::acs::pageroot
+    The default is $::acs::pageroot
     
     @return The page root
     
     @see publish::get_template_root
     @see publish::get_publish_roots
-    
 } {
     # LARS TODO: This parameter doesn't exist, it's a remnant from the CMS package
     set root_path [parameter::get \
                        -package_id [ad_conn package_id] \
                        -parameter PageRoot]
     
-    if { [string index $root_path 0] != "/" } {
+    if { [string index $root_path 0] ne "/" } {
         # Relative path, prepend server_root
-        set root_path "[ns_info pageroot]/$root_path"
+        set root_path "$::acs::pageroot/$root_path"
     }
     
     return [ns_normalizepath $root_path]
@@ -62,7 +61,7 @@ ad_proc -public publish::get_publish_roots {} {
     set page_root [publish::get_page_root]
     set absolute_paths [list]
     foreach path $root_paths {
-        if { [string index $path 0] != "/" } {
+        if { [string index $path 0] ne "/" } {
             lappend absolute_paths [ns_normalizepath "$page_root/$path"]
         } else {
             lappend absolute_paths $path
@@ -79,7 +78,7 @@ ad_proc -public publish::mkdirs { path } {
 } {
     set index [string last "/" $path]
     if { $index != -1 } {
-        file mkdir [string range $path 0 [expr $index - 1]]
+        file mkdir [string range $path 0 [expr {$index - 1}]]
     } 
 }
 
@@ -200,9 +199,7 @@ ad_proc -public publish::proc_exists { namespace_name proc_name } {
 
 } {
 
-  return [expr ![string equal \
-                  [namespace eval $namespace_name \
-                    "info procs $proc_name"] {}]]
+  return [expr {[namespace eval $namespace_name "info commands $proc_name"] ne ""}]
 }
 
 ##########################################################
@@ -271,7 +268,7 @@ ad_proc -public publish::handle_binary_file {
   set error_msg ""
 
   if { [template::util::is_nil opts(revision_id)] } {
-    set revision_id [item::get_live_revision $item_id]
+    set revision_id [::content::item::get_live_revision -item_id $item_id]
   } else {
     set revision_id $opts(revision_id)
   }
@@ -349,14 +346,14 @@ ad_proc -public publish::item_include_tag { item_id {extra_args {}} } {
  
   @return The HTML for the include tag
  
-  @see item::get_url
+  @see content::item::get_virtual_path
   @see publish::html_args
 
 } {
 
   # Concatenate all the extra html arguments into a string
   set extra_html [publish::html_args $extra_args]""
-  set item_url [item::get_url $item_id]
+  set item_url [::content::item::get_virtual_path -item_id $item_id]
   return "<include src=\"$item_url\" $extra_html item_id=$item_id>"
 }
 
@@ -443,7 +440,7 @@ ad_proc -private publish::merge_with_template { item_id args } {
 
 } {
   #set ::content::item_id $item_id
-  set ::content::item_url [item::get_url $item_id]
+  set ::content::item_url [::content::item::get_virtual_path -item_id $item_id]
 
   template::util::get_opts $args
 
@@ -451,13 +448,13 @@ ad_proc -private publish::merge_with_template { item_id args } {
   if { ![template::util::is_nil opts(revision_id)] } {
     set revision_id $opts(revision_id)
   } else {
-    set revision_id [item::get_live_revision $item_id]
+    set revision_id [::content::item::get_live_revision -item_id $item_id]
   }
 
   # Get the template 
-  set ::content::template_url [item::get_template_url $item_id]    
+  set ::content::template_url [::content::item::get_template -item_id $item_id -use_context public]
 
-  if { [string equal $::content::template_url {}] } { 
+  if {$::content::template_url eq {}} { 
     ns_log Warning "publish::merge_with_template: no template for item $item_id"
     return "" 
   }
@@ -495,7 +492,7 @@ ad_proc -public publish::handle::text { item_id args } {
   template::util::get_opts $args
 
   if { [template::util::is_nil opts(revision_id)] } {
-    set revision_id [item::get_live_revision $item_id]
+    set revision_id [::content::item::get_live_revision -item_id $item_id]
   } else {
     set revision_id $opts(revision_id)
   } 
@@ -626,7 +623,7 @@ ad_proc -private publish::get_main_revision_id {} {
 
   if { [template::util::is_nil ::content::revision_id] } {
     set item_id [get_main_item_id]
-    set ret [item::get_live_revision $item_id]
+    set ret [::content::item::get_live_revision -item_id $item_id]
   } else {
     set ret $::content::revision_id
   }
@@ -683,7 +680,7 @@ ad_proc -private publish::handle_item { item_id args } {
 
   # Process options
   if { [template::util::is_nil opts(revision_id)] } {
-    set revision_id [item::get_live_revision $item_id]
+    set revision_id [::content::item::get_live_revision -item_id $item_id]
   } else {
     set revision_id $opts(revision_id)
   }
@@ -812,13 +809,13 @@ ad_proc -public publish::render_subitem {
 } {
   # Get the child item
 
-  if { [string equal $relation_type child] } {
+  if {$relation_type eq "child"} {
       set subitems [db_list rs_get_subitems ""]
   } else {
       set subitems [db_list cs_get_subitems_related ""]
   }
 
-  set sub_item_id [lindex $subitems [expr $index - 1]]
+  set sub_item_id [lindex $subitems [expr {$index - 1}]]
 
   if { [template::util::is_nil sub_item_id] } {
     ns_log notice "publish::render_subitem: No such subitem"
@@ -828,7 +825,7 @@ ad_proc -public publish::render_subitem {
   # Call the appropriate handler function
   set code [list handle_item $sub_item_id -html $extra_args]
 
-  if { [string equal $is_embed t] } {
+  if {$is_embed eq "t"} {
     lappend code -embed
   }
 
