@@ -24,7 +24,7 @@ ad_library {
     @author Jeff Davis
     @author Peter Marklund (peter@collaboraid.biz)
     @author Lars Pind (lars@collaboraid.biz)
-    @cvs-id $Id: lang-catalog-procs.tcl,v 1.49 2009/03/31 20:13:30 emmar Exp $
+    @cvs-id $Id: lang-catalog-procs.tcl,v 1.49.8.3 2013/08/27 12:20:35 gustafn Exp $
 }
 
 namespace eval lang::catalog {}
@@ -80,7 +80,7 @@ ad_proc -private lang::catalog::all_messages_for_package_and_locale { package_ke
 
     @author Peter Marklund
 } {
-    db_multirow -local -upvar_level 2 all_messages get_messages {}
+    return [db_list_of_lists get_messages {}]
 }
     
 ad_proc -private lang::catalog::package_catalog_dir { package_key } {
@@ -232,14 +232,14 @@ ad_proc -private lang::catalog::messages_in_db {
 } {
     set message_list [list]
 
-    all_messages_for_package_and_locale $package_key $locale
-    template::util::multirow_foreach all_messages {
-        lappend message_list @all_messages.message_key@ @all_messages.message@
+    foreach message_tuple [all_messages_for_package_and_locale $package_key $locale] {
+        lassign $message_tuple message_key message description
+        lappend message_list $message_key $message
     }
-
     return $message_list
 }
 
+
 ad_proc -private lang::catalog::last_sync_messages {
     {-package_key:required}
     {-locale:required}
@@ -357,7 +357,7 @@ ad_proc -private lang::catalog::export_to_file {
    set message_count "0"
    foreach message_key $message_key_list {
        puts $catalog_file_id "  <msg key=\"[ad_quotehtml $message_key]\">[ad_quotehtml $messages_array($message_key)]</msg>"
-       if { [exists_and_not_null descriptions_array($message_key)] && $filename_info(locale) eq "en_US" } {
+       if { ([info exists descriptions_array($message_key)] && $descriptions_array($message_key) ne "") && $filename_info(locale) eq "en_US" } {
            puts $catalog_file_id "  <description key=\"[ad_quotehtml $message_key]\">[ad_quotehtml $descriptions_array($message_key)]</description>\n"
        }
        incr message_count
@@ -403,12 +403,12 @@ ad_proc -public lang::catalog::export {
 		# Get messages and descriptions for the locale
 		set messages_list [list]
 		set descriptions_list [list]
-		all_messages_for_package_and_locale $package_key $locale
-		template::util::multirow_foreach all_messages {
-		    lappend messages_list @all_messages.message_key@ @all_messages.message@
-		    lappend descriptions_list @all_messages.message_key@ @all_messages.description@
+		foreach message_tuple [all_messages_for_package_and_locale $package_key $locale] {
+            lassign $message_tuple message_key message description
+ 		    lappend messages_list $message_key $message
+ 		    lappend descriptions_list $message_key description
 		}
-		
+
 		set catalog_file_path [get_catalog_file_path \
 					   -package_key $package_key \
 					   -locale $locale]
