@@ -8,11 +8,11 @@ ad_library {
     http://www.fsf.org/copyleft/gpl.html
 
     @creation-date 10 September 2000
-    @author Jeff Davis (davis@arsdigita.com)
+    @author Jeff Davis (davis@xarg.net)
     @author Bruno Mattarollo (bruno.mattarollo@ams.greenpeace.org)
     @author Peter Marklund (peter@collaboraid.biz)
     @author Lars Pind (lars@collaboraid.biz)
-    @cvs-id $Id: lang-message-procs.tcl,v 1.42.2.2 2004/03/18 10:12:37 peterm Exp $
+    @cvs-id $Id: lang-message-procs.tcl,v 1.51.8.1 2013/08/27 12:20:35 gustafn Exp $
 }
 
 namespace eval lang::message {}
@@ -86,14 +86,14 @@ ad_proc -public lang::message::register {
     set key_exists_p [db_string message_key_exists_p {}]
 
     if { ! $key_exists_p } {
-        if { [string equal $locale "en_US"] } {
+        if {$locale eq "en_US"} {
             db_dml insert_message_key {}
         } else {
             # Non-default locale
             # The system will not function correctly if there are keys registered in other locales
             # than en_US that are not present for en_US. This introduces the inconvenience of having to
             # register the en_US messages first, but that is manageable
-            set error_message "lang::message::register - refusing to register message for non-en_US locale ${locale}. The message key ${package_key}.${message_key} bust be registered in en_US first"
+            set error_message "lang::message::register - refusing to register message for non-en_US locale ${locale}. The message key ${package_key}.${message_key} must be registered in en_US first"
             ns_log Error $error_message
             error $error_message
         }
@@ -103,7 +103,7 @@ ad_proc -public lang::message::register {
     # Exclude the special case of datetime configuration messages in acs-lang. An alternative
     # to treating those messages as a special case here would be to have those messages use
     # quoted percentage signs (double percentage signs).
-    if { ![string equal $locale "en_US"] && ![regexp {^acs-lang\.localization-} $key] } {
+    if { $locale ne "en_US" && ![regexp {^acs-lang\.localization-} $key] } {
         set embedded_vars [get_embedded_vars $message]
         set embedded_vars_en_us [get_embedded_vars [lang::message::lookup en_US $key {} {} 0]]
         set missing_vars [util_get_subset_missing $embedded_vars $embedded_vars_en_us]
@@ -120,7 +120,7 @@ ad_proc -public lang::message::register {
     } else {
         set cols(sync_time) "null"
     } 
-    if { [empty_string_p [string trim $message]] } {
+    if { [string trim $message] eq "" } {
         set cols(message) "null"
     } else {
         set cols(message) [db_map message]
@@ -168,7 +168,7 @@ ad_proc -public lang::message::register {
                 $old_message_array(upgrade_status)
             
             # Trying to avoid hitting Oracle bug#2011927    
-            if { [empty_string_p [string trim $message]] } {
+            if { [string trim $message] eq "" } {
                 db_dml lang_message_null_update {}
             } else { 
                 set cols(message) [db_map message]
@@ -197,7 +197,7 @@ ad_proc -public lang::message::register {
         }
         
         # avoiding bug#2011927 from Oracle.
-        if { [empty_string_p [string trim $message]] } {
+        if { [string trim $message] eq "" } {
             db_dml lang_message_insert_null_msg {}
         } else {
             db_dml lang_message_insert {} -clobs [list $message]
@@ -423,7 +423,7 @@ ad_proc -private lang::message::edit {
                 $old_message_array(upgrade_status)            
 
             # If we are deleting an en_US message we need to mark the message deleted in all locales
-            if { [string equal $locale "en_US"] } {
+            if {$locale eq "en_US"} {
                 set message_locales [db_list all_message_locales {
                     select locale
                     from lang_messages
@@ -480,7 +480,7 @@ ad_proc -public lang::message::conflict_count {
     # Build any package and locale where clauses
     set where_clauses [list]
     foreach col {package_key locale} {
-        if { ![empty_string_p [set $col]] } {
+        if { [set $col] ne "" } {
             lappend where_clauses "$col = :${col}"
         }
     }
@@ -537,7 +537,7 @@ ad_proc -private lang::message::get_embedded_vars {
     while { [regexp [embedded_vars_regexp] $remaining_message \
             match before_percent percent_match remaining_message] } {
 
-        if { [string equal $percent_match "%%"] } {
+        if {$percent_match eq "%%"} {
             # A quoted percentage sign - ignore
             continue
         } else {
@@ -579,7 +579,7 @@ ad_proc -private lang::message::format {
 
         append formated_message $before_percent
 
-        if { [string equal $percent_match "%%"] } {
+        if {$percent_match eq "%%"} {
             # A quoted percent sign
             append formated_message "%"
         } else {
@@ -607,7 +607,7 @@ ad_proc -private lang::message::format {
                 upvar $upvar_level $variable_name local_variable
 
                 if { [info exists local_variable] } {
-                    if { ![exists_and_not_null array_key] } {
+                    if { (![info exists array_key] || $array_key eq "") } {
                         # Normal Tcl variable
                         append formated_message $local_variable
                     } else {
@@ -686,7 +686,7 @@ ad_proc -public lang::message::lookup {
     @param default            Text to return if there is no message in the message catalog for
                               the given locale. This argument is optional. If this argument is
                               not provided or is the empty string then the text returned will
-                              be TRANSLATION MISSING - $key.
+                              be TRANSLATION MISSING - $key. 
 
     @param substitution_list  A list of values to substitute into the message. This argument should
                               only be given for certain messages that contain place holders (on the syntax
@@ -703,7 +703,7 @@ ad_proc -public lang::message::lookup {
                               Useful if you're not using this message in the page itself, but e.g.
                               for localization data or for the list of messages on the page.
 
-    @author Jeff Davis (davis@arsdigita.com)
+    @author Jeff Davis (davis@xarg.net)
     @author Henry Minsky (hqm@arsdigita.com)
     @author Peter Marklund (peter@collaboraid.biz)
 
@@ -715,7 +715,13 @@ ad_proc -public lang::message::lookup {
     # Make sure messages are in the cache
     cache
 
-    if { [empty_string_p $locale] } {
+    # Make sure that a default of "" is transformed into Translation Missing
+    # As per discussion on IRC on 2008-03-06
+    if { $default eq ""} {
+	set default "TRANSLATION MISSING"
+    }
+    
+    if { $locale eq "" } {
         # No locale provided
 
         if { [ad_conn isconnected] } {
@@ -728,7 +734,7 @@ ad_proc -public lang::message::lookup {
     } elseif { [string length $locale] == 2 } {
         # Only language provided, let's get the default locale for this language
         set default_locale [lang::util::default_locale_from_lang $locale]
-        if { [empty_string_p $default_locale] } {
+        if { $default_locale eq "" } {
             error "Could not look up locale for language $locale"
         } else {
             set locale $default_locale
@@ -764,9 +770,18 @@ ad_proc -public lang::message::lookup {
                     if { [message_exists_p $locale $key] } {
                         set message [nsv_get lang_message_$locale $key]
                     } else {
-                        ns_log Error "lang::message::lookup: Key '$key' does not exist in en_US"
-                        set message "MESSAGE KEY MISSING: '$key'"
-                    }
+			if {"TRANSLATION MISSING" != $default} {
+			    set message $default
+			} else {
+			    if {[string match "acs-translations.*" $key]} {
+				ns_log Debug "lang::message::lookup: Key '$key' does not exist in en_US"
+				set message "MESSAGE KEY MISSING: '$key'"
+			    } else {
+				ns_log Error "lang::message::lookup: Key '$key' does not exist in en_US"
+				set message "MESSAGE KEY MISSING: '$key'"
+			    }
+			}
+		    }
                 }
             }
         }
@@ -775,7 +790,7 @@ ad_proc -public lang::message::lookup {
     # Do any variable substitutions (interpolation of variables)
     # Set upvar_level to 0 and substitution_list empty to prevent substitution from happening
     if { [llength $substitution_list] > 0 || ($upvar_level >= 1 && [string first "%" $message] != -1) } {
-        set message [lang::message::format $message $substitution_list [expr $upvar_level + 1]]
+        set message [lang::message::format $message $substitution_list [expr {$upvar_level + 1}]]
     }
 
     if { [lang::util::translator_mode_p] } {
@@ -819,7 +834,7 @@ ad_proc -private lang::message::translate {
     set url "http://babel.altavista.com/translate.dyn?doit=done&BabelFishFrontPage=yes&bblType=urltext&url="
     set babel_result [ns_httpget "$url&lp=$lang&urltext=[ns_urlencode $qmsg]"]
     set result_pattern "$marker (\[^<\]*)"
-    if [regexp -nocase $result_pattern $babel_result ignore msg_tr] {
+    if {[regexp -nocase $result_pattern $babel_result ignore msg_tr]} {
         regsub "$marker." $msg_tr "" msg_tr
         return [string trim $msg_tr]
     } else {
@@ -840,7 +855,7 @@ ad_proc -private lang::message::cache {
     if { ![nsv_exists lang_message_cache executed_p] } {            
         nsv_set lang_message_cache executed_p 1
 
-        if { [empty_string_p $package_key] } {
+        if { $package_key eq "" } {
             set package_where_clause ""
         } else {
             set package_where_clause "where package_key = :package_key"
@@ -878,7 +893,7 @@ ad_proc -public _mr { locale key message } {
 
     package_key.message_key
 
-    @author Jeff Davis (davis@arsdigita.com)
+    @author Jeff Davis (davis@xarg.net)
     
     @param locale  Abbreviation for language of the message or the locale.
     @param key     Unique identifier for this message. Will be the same identifier
@@ -921,7 +936,7 @@ ad_proc -public _ {
 
     @return           A localized message
     
-    @author Jeff Davis (davis@arsdigita.com)
+    @author Jeff Davis (davis@xarg.net)
     @author Peter Marklund (peter@collaboraid.biz)
     @author Christian Hvid (chvid@collaboraid.biz)
 
@@ -937,57 +952,6 @@ ad_proc -public _ {
 #
 #####
 
-ad_proc -private -deprecated -warn lang_message_register { locale key message } { 
-
-    Normally accessed through the _mr procedure.
-    Registers a message in a given locale or language.
-    Inserts the message into the table lang_messages
-    if it does not exist and updates if it does.
-
-    @author Jeff Davis (davis@arsdigita.com)
-    @author Bruno Mattarollo (bruno.mattarollo@ams.greenpeace.org)
-    @see _mr
-    
-    @param locale  Locale or language of the message. If a language is supplied,
-                   the default locale for the language is looked up. 
-                   Taken from ad_locales table.
-    @param key     Unique identifier for this message. Will be the same identifier
-                   for each language
-    @param message Text of the message
-    
-    @see lang::message::register
-} { 
-    return [lang::message::register $locale $key $message]
-}
-
-ad_proc -private -deprecated -warn lang_message_lookup {
-    locale
-    key
-    {default "TRANSLATION MISSING"}
-} {    
-    @see lang::message::lookup
-} { 
-    return [lang::message::lookup $locale $key $default {} 2]
-}
-
-ad_proc -deprecated -warn lang_babel_translate { 
-    msg
-    lang
-} {
-    Translates an English string into a different language
-    using Babelfish.
-
-    @author            Henry Minsky (hqm@mit.edu)
-
-    @param msg         String to translate
-    @param lang        Abbreviation for lang in which to translate string
-    @return            Translated string
-
-    @see lang::message::translate
-} {
-    return [lang::message::translate $msg $lang]
-}     
-
 
 ad_proc -public lang::message::update_description {
     {-package_key:required}
@@ -997,7 +961,7 @@ ad_proc -public lang::message::update_description {
     @author Simon Carstensen
     @creation_date 2003-08-12
 } {
-    if { [empty_string_p [string trim $description]] } {
+    if { [string trim $description] eq "" } {
         db_dml update_description_insert_null {}
     } else {
         db_dml update_description {} -clobs [list $description]
