@@ -14,7 +14,7 @@ ad_library {
     @author Peter Marklund (peter@collaboraid.biz)
     @author Lars Pind (lars@collaboraid.biz)
     @author Christian Hvid
-    @cvs-id $Id: lang-util-procs.tcl,v 1.46 2010/01/08 17:39:58 emmar Exp $
+    @cvs-id $Id: lang-util-procs.tcl,v 1.47.2.1 2013/08/27 12:20:35 gustafn Exp $
 }
 
 namespace eval lang::util {}
@@ -367,7 +367,9 @@ ad_proc -public lang::util::charset_for_locale {
     @return        IANA MIME character set name
 } {
     # DRB: cache this now that ad_conn tracks it
-    return [db_string -cache_key ad_lang_mime_charset_$locale charset_for_locale {}]
+    set key ::lang::util::charset_for_locale($locale)
+    if {[info exists $key]} {return [set $key]}
+    set $key [db_string -cache_key ad_lang_mime_charset_$locale charset_for_locale {}]
 }
 
 ad_proc -private lang::util::default_locale_from_lang_not_cached { 
@@ -747,7 +749,7 @@ ad_proc -private lang::util::escape_vars_if_not_null {
 } {
     foreach lm $list {
 	upvar $lm foreign_var
-	if { [exists_and_not_null foreign_var] } {
+	if { ([info exists foreign_var] && $foreign_var ne "") } {
 	    set foreign_var "\[$foreign_var\]"
 	}
     }
@@ -781,7 +783,7 @@ ad_proc -public lang::util::convert_to_i18n {
 	
 	# Register the language keys
 	lang::message::register en_US $package_key $message_key $text
-	if {[exists_and_not_null locale]} {
+	if {([info exists locale] && $locale ne "")} {
 	    lang::message::register $locale $package_key $message_key $text
 	}
 	
