@@ -10,26 +10,10 @@ ad_library {
     @creation-date 30 September 2000
     @author Jeff Davis (davis@xarg.net) 
     @author Ashok Argent-Katwala (akatwala@arsdigita.com)
-    @cvs-id $Id: localization-procs.tcl,v 1.14.4.1 2004/09/30 17:42:25 andrewg Exp $
+    @cvs-id $Id: localization-procs.tcl,v 1.23.8.1 2013/08/27 12:20:35 gustafn Exp $
 }
 
 
-ad_proc -private ad_locale_escape_vars_if_not_null {
-    list
-} {
-    Processes a list of variables before they are passed into
-    a regexp command.
-
-    @param list   List of variable names
-} {
-    foreach lm $list {
-	upvar $lm foreign_var
-	if { [exists_and_not_null foreign_var] } {
-	    set foreign_var "\[$foreign_var\]"
-	}
-    }
-}
-
 ad_proc -public lc_parse_number { 
     num 
     locale 
@@ -55,7 +39,7 @@ ad_proc -public lc_parse_number {
     @return         Canonical form of the number
 
 } {
-    if {[empty_string_p $num]} {
+    if {$num eq ""} {
 	return ""
     }
 
@@ -64,7 +48,7 @@ ad_proc -public lc_parse_number {
     set neg [lc_get -locale $locale "negative_sign"]
     set pos [lc_get -locale $locale "positive_sign"]
 
-    ad_locale_escape_vars_if_not_null {dec thou neg pos}
+    lang::util::escape_vars_if_not_null {dec thou neg pos}
 
     # Pattern actually looks like this (separators notwithstanding):
     # {^\ *([-]|[+])?\ *([0-9]+|[1-9][0-9]{1,2}([,][0-9]{3})+)([.][0-9]*)?\ *$}
@@ -97,7 +81,7 @@ ad_proc -public lc_parse_number {
 	
 	# if number is real and mod(number)<1, then we have pulled off the leading zero; i.e. 0.231 -> .231 -- this is still fine for tcl though...
 	# Last pathological case
-	if {![string compare "." $number]} {
+	if {"." eq $number } {
 	    set number 0
 	}
 
@@ -139,11 +123,14 @@ ad_proc -private lc_sepfmt {
 } {
     # with empty seperator or grouping string we behave 
     # posixly
-    if {[empty_string_p $grouping] 
-        || [empty_string_p $sep] } { 
+    if {$grouping eq "" 
+        || $sep eq "" } { 
         return $num
     }
     
+    # we need to sanitize the subspec
+    regsub -all -- "(\[&\\\\\])" $sep "\\\\\\1" sep
+
     set match "^(-?$num_re+)("
     set group [lindex $grouping 0]
     
@@ -178,7 +165,7 @@ ad_proc -public lc_numeric {
     @return         Localized form of the number
 
 } { 
-    if {![empty_string_p $fmt]} { 
+    if {$fmt ne ""} { 
         set out [format $fmt $num]
     } else { 
         set out $num
@@ -189,9 +176,12 @@ ad_proc -public lc_numeric {
     set grouping [lc_get -locale $locale "grouping"]
 
     # Fall back on en_US if grouping is not on valid format
-    if { ![string equal $locale en_US] && ![regexp {^[0-9 ]+$} $grouping] } {
+    if { $locale ne "en_US" && ![regexp {^[0-9 -]+$} $grouping] } {
         ns_log Warning "lc_numeric: acs-lang.localization-grouping key has invalid value $grouping for locale $locale"
-        return [lc_numeric $num $fmt en_US]
+        set sep ,
+        set dec .
+        set grouping 3
+        
     }
     
     regsub {\.} $out $dec out
@@ -225,7 +215,7 @@ ad_proc -public lc_monetary_currency {
     }
     
     if { $label_p } {
-	if {[string compare $style int] == 0} {
+	if {$style eq "int" } {
 	    set use_as_label $currency
 	} else {
 	    set use_as_label $html_entity
@@ -259,11 +249,11 @@ ad_proc -private lc_monetary {
     @return            Formatted monetary amount
 } { 
 
-    if {![empty_string_p $forced_frac_digits] && [string is integer $forced_frac_digits]} {
+    if {$forced_frac_digits ne "" && [string is integer $forced_frac_digits]} {
 	set dig $forced_frac_digits
     } else {
 	# look up the digits
-	if {[string compare $style int] == 0} { 
+	if {$style eq "int" } { 
 	    set dig [lc_get -locale $locale "int_frac_digits"]
 	} else { 
 	    set dig [lc_get -locale $locale "frac_digits"]
@@ -272,7 +262,7 @@ ad_proc -private lc_monetary {
 
     # figure out if negative 
     if {$num < 0} { 
-        set num [expr abs($num)]
+        set num [expr {abs($num)}]
         set neg 1
     } else { 
         set neg 0
@@ -282,9 +272,9 @@ ad_proc -private lc_monetary {
     set out [format "%.${dig}f" $num]
 
     # look up the label if needed 
-    if {[empty_string_p $forced_currency_symbol]} {
+    if {$forced_currency_symbol eq ""} {
 	if {$label_p} {
-	    if {[string compare $style int] == 0} { 
+	    if {$style eq "int" } { 
 		set sym [lc_get -locale $locale "int_curr_symbol"]
 	    } else { 
 		set sym [lc_get -locale $locale "currency_symbol"]
@@ -421,11 +411,11 @@ ad_proc -public lc_time_fmt {
                            (or have an 'on this day in history' style page that goes back a good few hundred years).
     @return                A date formatted for a locale
 } {
-    if { [empty_string_p $datetime] } {
+    if { $datetime eq "" } {
         return ""
     }
 
-    if { ![exists_and_not_null locale] } {
+    if { (![info exists locale] || $locale eq "") } {
         set locale [ad_conn locale]
     }
     
@@ -448,8 +438,8 @@ ad_proc -public lc_time_fmt {
     }
 
     set a [expr (14 - $lc_time_month) / 12]
-    set y [expr $lc_time_year - $a]
-    set m [expr $lc_time_month + 12*$a - 2]
+    set y [expr {$lc_time_year - $a}]
+    set m [expr {$lc_time_month + 12*$a - 2}]
     
     # day_no becomes 0 for Sunday, through to 6 for Saturday. Perfect for addressing zero-based lists pulled from locale info.
     set lc_time_day_no [expr (($lc_time_days + $y + ($y/4) - ($y / 100) + ($y / 400)) + ((31*$m) / 12)) % 7]
@@ -517,7 +507,7 @@ ad_proc -public lc_time_utc_to_local {
     @param tz                Timezone that must exist in tz_data table.
     @return                  Local time
 } {
-    if { [empty_string_p $tz] } {
+    if { $tz eq "" } {
         set tz [lang::conn::timezone]
     }
 
@@ -530,7 +520,7 @@ ad_proc -public lc_time_utc_to_local {
 	ns_log Warning "lc_time_utc_to_local: Query exploded on time conversion from UTC, probably just an invalid date, $time_value: $errmsg"
     }
 
-    if {[empty_string_p $local_time]} {
+    if {$local_time eq ""} {
 	# If no conversion possible, log it and assume local is as given (i.e. UTC)	    
 	ns_log Notice "lc_time_utc_to_local: Timezone adjustment in ad_localization.tcl found no conversion to UTC for $time_value $tz"	
     }
@@ -548,7 +538,7 @@ ad_proc -public lc_time_local_to_utc {
     @param tz                Timezone that must exist in tz_data table.
     @return                  UTC time.
 } {
-    if { [empty_string_p $tz] } {
+    if { $tz eq "" } {
         set tz [lang::conn::timezone]
     }
 
@@ -560,7 +550,7 @@ ad_proc -public lc_time_local_to_utc {
 	ns_log Warning "lc_time_local_to_utc: Query exploded on time conversion to UTC, probably just an invalid date, $time_value: $errmsg"
     }
 
-    if {[empty_string_p $utc_time]} {
+    if {$utc_time eq ""} {
 	# If no conversion possible, log it and assume local is as given (i.e. UTC)	    
 	ns_log Notice "lc_time_local_to_utc: Timezone adjustment in ad_localization.tcl found no conversion to local time for $time_value $tz"	
     }
@@ -587,7 +577,7 @@ ad_proc -public lc_time_system_to_conn {
     set system_tz [lang::system::timezone]
     set conn_tz [lang::conn::timezone]
 
-    if { [empty_string_p $conn_tz] || [string equal $system_tz $conn_tz] } {
+    if { $conn_tz eq "" || $system_tz eq $conn_tz } {
         return $time_value
     }
 
@@ -610,7 +600,7 @@ ad_proc -public lc_time_conn_to_system {
     set system_tz [lang::system::timezone]
     set conn_tz [lang::conn::timezone]
 
-    if { [empty_string_p $conn_tz] || [string equal $system_tz $conn_tz] } {
+    if { $conn_tz eq "" || $system_tz eq $conn_tz } {
         return $time_value
     }
 
