@@ -6,7 +6,7 @@ ad_page_contract {
     @author Bruno Mattarollo <bruno.mattarollo@ams.greenpeace.org>
     @author Christian Hvid
     @creation-date 30 October 2001
-    @cvs-id $Id: edit-localized-message.tcl,v 1.17 2008/12/30 22:09:37 emmar Exp $
+    @cvs-id $Id: edit-localized-message.tcl,v 1.17.8.1 2013/08/27 12:20:36 gustafn Exp $
 
 } {
     locale
@@ -117,7 +117,7 @@ ad_form -extend -name message -form {
         and    cu.user_id = lm.creation_user
     }]
 
-    if { [exists_and_not_null message] } {
+    if { ([info exists message] && $message ne "") } {
         set message $message
     } else {
         set message $original_message
