@@ -4,7 +4,7 @@ ad_library {
     
     @author Eric Lorenzo (eric@openforce.net)
     @creation-date 22 March 2002
-    @cvs-id $Id: acs-mail-lite-procs.tcl,v 1.89 2011/03/29 09:53:13 gustafn Exp $
+    @cvs-id $Id: acs-mail-lite-procs.tcl,v 1.90.2.1 2013/08/28 22:53:44 michaels Exp $
 
 }
 
@@ -312,10 +312,10 @@ namespace eval acs_mail_lite {
                             -use_sender_p $use_sender_p        
                     } errMsg]
                     if {$err} {
-                        ns_log Error "Error while sending queued mail: $errMsg"
-                        # release the lock
-                        set locking_server ""
-                        db_dml lock_queued_message {}    
+                        ns_log Error "Could not send queued mail (message $return_id): $errMsg"
+                        # release the lock (MS not now)
+                        # set locking_server ""
+                        # db_dml lock_queued_message {}    
                     } else {
                         # mail was sent, delete the queue entry
                         db_dml delete_queue_entry {}
@@ -441,8 +441,8 @@ namespace eval acs_mail_lite {
 
         # Set the subject
         if { $subject ne "" } {
-            set subject [acs_mail_lite::utils::build_subject $subject]
-            mime::setheader $tokens Subject $subject
+            set encoded_subject [acs_mail_lite::utils::build_subject $subject]
+            mime::setheader $tokens Subject $encoded_subject
         }
 
         # Add extra headers
