@@ -3,7 +3,7 @@ ad_library {
     
     @author Neophytos Demetriou
     @creation-date 2001-09-01
-    @cvs-id $Id: acs-service-contract-procs.tcl,v 1.24 2010/10/30 21:43:01 gustafn Exp $
+    @cvs-id $Id: acs-service-contract-procs.tcl,v 1.25.2.2 2013/08/27 11:20:39 gustafn Exp $
 }
 
 namespace eval acs_sc {}
@@ -22,11 +22,12 @@ ad_proc -public acs_sc::invoke {
     {-call_args {}}
     {-error:boolean}
 } {
-    A wrapper for the acs_sc_call procedure, with explicitly named
-    parameters so it's easier to figure out how to use it.
-    You must supply either contract and impl, or just impl_id.
+    A replacement of the former acs_sc_call procedure.
+    One must supply either contract and impl, or just impl_id.
     If you supply impl_id and contract, we throw an error if the impl_id's contract doesn't match
     the contract you passed in. If you supply both impl_id and impl, we throw an error.
+
+    Additional documentation and commentary at http://openacs.org/forums/message-view?message_id=108614.
     
     @param contract_name The name of the contract you wish to use.
     @param operation_name The name of the operation in the contract you wish to call.
@@ -34,12 +35,13 @@ ad_proc -public acs_sc::invoke {
     @param impl_id The ID of the implementation you wish to use.
     @param args The arguments you want to pass to the proc.
     @param error If specified, will throw an error if the operation isn't implemented.
+
     
     @author Lars Pind (lars@collaboraid.biz)
     @see acs_sc_call
 } {
-    if { [exists_and_not_null impl_id] } {
-        if { [exists_and_not_null impl] } {
+    if { $impl_id ne "" } {
+        if { $impl ne "" } {
             error "Cannot supply both impl and impl_id"
         }
         acs_sc::impl::get -impl_id $impl_id -array impl_info
@@ -49,10 +51,22 @@ ad_proc -public acs_sc::invoke {
         }
         set contract $impl_info(impl_contract_name)
     }
-    if { ![exists_and_not_null impl] || ![exists_and_not_null contract] } {
+    if { $impl eq "" || $contract eq "" } {
         error "You must supply either impl_id, or contract and impl to acs_sc::invoke"
     }
-    return [acs_sc_call -error=$error_p $contract $operation $call_args $impl]
+
+    set proc_name [acs_sc_generate_name $contract $impl $operation]
+
+    if { [info commands $proc_name] ne "" } {
+	return [ad_apply $proc_name $call_args]
+    } 
+
+    if { $error_p } {
+	error "Operation $operation is not implemented in '$impl' implementation of contract '$contract'"
+    } else {
+	ns_log warning "ACS-SC: Function Not Found: $proc_name [info commands $proc_name]"
+    }
+    return
 }
 
 
@@ -118,9 +132,6 @@ ad_proc -private acs_sc_get_alias {
 
 }
 
-
-
-
 ad_proc -private acs_sc_proc {
     contract
     operation
@@ -128,7 +139,7 @@ ad_proc -private acs_sc_proc {
     {impl_alias {}}
     {impl_pl {}}
 } {
-    Builds the proc used by acs_sc_call, generally only called 
+    Builds the proc used by acs_sc::invoke, generally only called 
     in acs-service-contract-init.tcl at startup.
 
     @return 0 on failure, 1 on success.
@@ -154,7 +165,7 @@ ad_proc -private acs_sc_proc {
         return 0
     }
 
-    append docblock "\n<b>acs-service-contract operation.  Call via acs_sc_call.</b>\n\n$operation_desc\n\n"
+    append docblock "\n<b>acs-service-contract operation.  Call via acs_sc::invoke.</b>\n\n$operation_desc\n\n"
 
     db_foreach operation_inputtype_element {*SQL*} {
 	lappend arguments "$element_name"
@@ -171,7 +182,7 @@ ad_proc -private acs_sc_proc {
 	}
     }
 
-    append docblock "\n@see $impl_alias\n@see acs_sc_call"
+    append docblock "\n@see $impl_alias\n@see acs_sc::invoke"
 
     set full_statement [acs_sc_get_statement $impl_alias $impl_pl $arguments]
 
@@ -230,9 +241,6 @@ ad_proc -private acs_sc_get_statement {
     return $full_statement
 }
 
-
-
-
 ad_proc -private -deprecated acs_sc_call {
     {-error:boolean}
     contract
@@ -252,19 +260,9 @@ ad_proc -private -deprecated acs_sc_call {
 
     @see acs_sc::invoke
 } {
-    set proc_name [acs_sc_generate_name $contract $impl $operation]
+    acs_sc::invoke -contract $contract -operation $operation -impl $impl -call_args $arguments -error=$error_p
+} 
 
-    if { [llength [info procs $proc_name]] == 1 } {
-	return [ad_apply $proc_name $arguments]
-    } else {
-        if { $error_p } {
-            error "Operation $operation is not implemented in '$impl' implementation of contract '$contract'"
-        } else {
-            ns_log warning "ACS-SC: Function Not Found: $proc_name [info procs $proc_name]"
-        }
-	return
-    }
-}
 
 
 ##
