@@ -6,7 +6,7 @@ ad_library {
 
     @author mbryzek@arsdigita.com
     @creation-date Thu Dec  7 18:13:56 2000
-    @cvs-id $Id: group-procs.tcl,v 1.37 2009/12/01 09:24:13 emmar Exp $
+    @cvs-id $Id: group-procs.tcl,v 1.38.2.1 2013/08/27 12:20:36 gustafn Exp $
 
 }
 
@@ -127,7 +127,7 @@ ad_proc -public group::new {
     # (through the pretty name). We just have to change the display of
     # groups to the title at the appropriate places.
 
-    if { [info procs "::lang::util::convert_to_i18n"] ne "" } {
+    if { [info commands "::lang::util::convert_to_i18n"] ne "" } {
 	set pretty_name [lang::util::convert_to_i18n -message_key "group_title_${group_id}" -text "$pretty_name"]
     } 
 	
@@ -262,11 +262,11 @@ ad_proc -private group::get_id_not_cached {
 
     @error
 } {
-    if {[exists_and_not_null subsite_id]} {
+    if {([info exists subsite_id] && $subsite_id ne "")} {
 	set application_group_id [application_group::group_id_from_package_id -package_id [ad_conn subsite_id]]
     } 
     
-    if {[exists_and_not_null application_group_id]} {
+    if {([info exists application_group_id] && $application_group_id ne "")} {
 	set group_ids [db_list get_group_id_with_application {}]
     } else {
 	set group_ids [db_list get_group_id {}]
