@@ -6,7 +6,7 @@ ad_library {
 
     @author mbryzek@arsdigita.com
     @creation-date Tue Dec 12 15:40:39 2000
-    @cvs-id $Id: rel-types-procs.tcl,v 1.10 2010/10/04 21:59:20 victorg Exp $
+    @cvs-id $Id: rel-types-procs.tcl,v 1.10.4.1 2013/08/27 12:20:36 gustafn Exp $
 }
 
 ad_page_contract_filter rel_type_dynamic_p {name value} {
@@ -255,7 +255,7 @@ namespace eval rel_types {
 
 	@return 1 if successful
     } {
-	if {![exists_and_not_null role]} {
+	if {![info exists role] || $role eq ""} {
 	    set role [util_text_to_url \
 			  -text $pretty_name \
 			  -replacement "_" \
