@@ -3,7 +3,7 @@ ad_page_contract {
 
     @author Lars Pind (lars@collaboraid.biz)
     @creation-date 2003-05-28
-    @cvs-id $Id: application-new.tcl,v 1.5 2007/01/10 21:22:08 gustafn Exp $
+    @cvs-id $Id: application-new.tcl,v 1.5.10.1 2013/08/27 12:20:37 gustafn Exp $
 }
 
 set page_title "New Application"
@@ -28,7 +28,7 @@ ad_form -name application -cancel_url . -form {
         {html {size 30}}
         {validate {
             empty_or_not_exists 
-            {expr \[empty_string_p \$value\] || \[catch { site_node::get_from_url -url "[ad_conn package_url]\$value/" -exact }\]}
+	  {\$value\ eq {} || \[catch { site_node::get_from_url -url "[ad_conn package_url]\$value/" -exact }\]}
             {This folder name is already used.}
         }}
     }
