@@ -4,7 +4,7 @@ ad_library {
 
     @author rhs@mit.edu
     @creation-date 2000-08-17
-    @cvs-id $Id: acs-permissions-procs.tcl,v 1.31 2010/02/09 22:39:47 emmar Exp $
+    @cvs-id $Id: acs-permissions-procs.tcl,v 1.32 2013/04/02 11:05:18 victorg Exp $
 
 }
 
@@ -131,7 +131,7 @@ ad_proc -private permission::permission_p_not_cached {
     # We have a thread-local cache here
     global permission__permission_p__cache
     if { ![info exists permission__permission_p__cache($party_id,$object_id,$privilege)] } {
-        set permission__permission_p__cache($party_id,$object_id,$privilege) [db_0or1row select_permission_p {}]
+        set permission__permission_p__cache($party_id,$object_id,$privilege) [expr {[db_exec_plsql select_permission_p {}] ? 1 : 0 }]
     }
     return $permission__permission_p__cache($party_id,$object_id,$privilege)
 }
