@@ -4,7 +4,7 @@ ad_library {
 
     @author Bryan Quinn (bquinn@arsdigita.com)
     @creation-date Fri Oct  6 21:46:05 2000
-    @cvs-id $Id: apm-file-procs.tcl,v 1.35 2008/12/24 00:20:46 gustafn Exp $
+    @cvs-id $Id: apm-file-procs.tcl,v 1.35.8.3 2013/08/26 07:10:52 gustafn Exp $
 } 
 
 
@@ -495,10 +495,19 @@ ad_proc -private apm_transfer_file {
   # reliably under windows, for unknown reasons the downloaded file is
   # truncated.
   #
-  # Therefore, we check first if the optional xotcl-core components
-  # are available...
+  # Therefore, we check first for the NaviServer built in ns_http, then 
+  # if the optional xotcl-core components are available...
   #
-  if {[info command ::xo::HttpRequest] ne ""} {
+  if {[info command ::ns_http] ne "" && [ns_info patchlevel] > "4.99.5"} {
+    # 
+    # ... use ns_http when we have a version with the "-file" flag ...
+    #
+    # ns_log notice "Transfer $url based to $output_file_name on ns_http"
+    set h [ns_http queue -timeout 60:0 $url]
+    ns_http wait -file F -spoolsize 1 $h
+    if {[file exists $output_file_name]} {file delete $output_file_name}
+    file rename $F $output_file_name
+  } elseif {[info command ::xo::HttpRequest] ne ""} {
     # 
     # ... use xo::HttpRequest...
     #
@@ -512,8 +521,8 @@ ad_proc -private apm_transfer_file {
 
   } elseif {[set wget [::util::which wget]] ne ""} {
     #
-    # ... if we have no ::xo::* and we have "wget" installed, we use
-    # it.
+    # ... if we have no ns_http, no ::xo::* and we have "wget"
+    # installed, we use it.
     #
     ns_log notice "Transfer $url based on wget"
     catch {exec $wget -O $output_file_name $url}
