@@ -4,7 +4,7 @@ ad_library {
 
     @creation-date September 11 2000
     @author Bryan Quinn (bquinn@arsdigita.com)
-    @cvs-id $Id: apm-install-procs.tcl,v 1.106 2010/10/17 21:06:09 donb Exp $
+    @cvs-id $Id: apm-install-procs.tcl,v 1.108.2.1 2013/08/27 11:01:48 gustafn Exp $
 }
 
 namespace eval apm {}
@@ -656,7 +656,7 @@ ad_proc -private apm_load_catalog_files {
     @author Peter Marklund
 } {
     # If acs-lang hasn't been installed yet we simply return
-    if { [llength [info proc lang::catalog::import]] == 0 || ![apm_package_installed_p acs-lang] } {
+    if { [info commands lang::catalog::import] eq "" || ![apm_package_installed_p acs-lang] } {
         return
     }
 
@@ -1408,7 +1408,7 @@ ad_proc -private apm_package_install_owners_prepare {owner_names owner_uris } {
 } {
     set owners [list]
     for {set i 0} {$i < [llength $owner_names] } {incr i} {
-	if { ![empty_string_p [lindex $owner_names $i]] } {
+	if { [lindex $owner_names $i] ne "" } {
 	    lappend owners [list [lindex $owner_names $i] [lindex $owner_uris $i]]
 	}
     }
@@ -1742,7 +1742,7 @@ ad_proc -private apm_data_model_scripts_find {
     set data_model_list [list]
     set upgrade_file_list [list]
     set ctl_file_list [list]
-    set file_list [apm_get_package_files -file_types $types_to_retrieve -package_path $package_path -package_key $package_key]
+    set file_list [apm_get_package_files -include_data_model_files -file_types $types_to_retrieve -package_path $package_path -package_key $package_key]
 
     foreach path $file_list {
         set file_type [apm_guess_file_type $package_key $path]
