@@ -5,7 +5,7 @@ ad_library {
     @creation-date 13 Apr 2000
     @author Bryan Quinn (bquinn@arsdigita.com)
     @author Jon Salz (jsalz@arsdigita.com)
-    @cvs-id $Id: apm-procs.tcl,v 1.89 2010/11/30 14:44:31 jeffd Exp $
+    @cvs-id $Id: apm-procs.tcl,v 1.94.2.1 2013/08/27 11:01:48 gustafn Exp $
 }
 
 namespace eval apm {}
@@ -391,13 +391,13 @@ ad_proc -private apm_mark_files_for_reload {
 	# which differs the mtime it had when last loaded, mark to be loaded.
 	if { [file isfile $full_path] } {
 	    set mtime [file mtime $full_path]
-
-	    if { $force_reload_p || (![nsv_exists apm_library_mtime $relative_path] || \
-		    [nsv_get apm_library_mtime $relative_path] != $mtime) } {
-
-		lappend changed_files $relative_path
+	    if { $force_reload_p 
+		 || (![nsv_exists apm_library_mtime $relative_path] 
+		     || [nsv_get apm_library_mtime $relative_path] != $mtime 
+		     || [clock seconds]-$mtime < 5) } {
+	        lappend changed_files $relative_path
 	    }
-	} 
+	}
     }
 
     if { [llength $changed_files] > 0 } {
@@ -425,9 +425,9 @@ ad_proc -private apm_mark_version_for_reload { version_id { changed_files_var ""
     if { $changed_files_var ne "" } {
 	upvar $changed_files_var changed_files
     }
-
+  ns_log notice "apm_mark_version_for_reload try to get package_key from $version_id"
     set package_key [apm_package_key_from_version_id $version_id]
-
+  ns_log notice "apm_mark_version_for_reload $package_key $version_id"
     set changed_files [list]
 
     set file_types [list tcl_procs query_file]
@@ -615,21 +615,26 @@ ad_proc -public apm_load_packages {
 
     # Load up the Automated Tests and associated Queries if necessary
     if {$load_tests_p} {
-      apm_load_libraries -force_reload=$force_reload_p -packages $packages -test_procs
-      apm_load_queries -packages $packages_to_load -test_queries
+	apm_load_libraries -force_reload=$force_reload_p -packages $packages -test_procs
+	apm_load_queries -packages $packages_to_load -test_queries
     }
 
     if { $load_libraries_p } {
         # branimir: acs-lang needs to be initialized before anything else
         # because there are packages whose *-init.tcl files depend on it.
-        apm_load_libraries -force_reload=$force_reload_p -init -packages acs-lang
-
-        apm_load_libraries -force_reload=$force_reload_p -init -packages $packages_to_load
+	apm_load_libraries -force_reload=$force_reload_p -init -packages acs-lang
+	set p [lsearch $packages_to_load acs-lang]
+	if {$p > -1} {
+	    set unique_packages [lreplace $packages_to_load $p $p]
+	} else {
+	    set unique_packages $packages_to_load
+	}
+        apm_load_libraries -force_reload=$force_reload_p -init -packages $unique_packages
     }
 
     # Load up the Automated Tests initialisation scripts if necessary
     if {$load_tests_p} {
-      apm_load_libraries -force_reload=$force_reload_p -packages $packages_to_load -test_init
+	apm_load_libraries -force_reload=$force_reload_p -packages $packages_to_load -test_init
     }
 }
 
@@ -1157,6 +1162,7 @@ ad_proc -public apm_version_get {
     db_1row select_version_info {} -column_array row
 }
 
+namespace eval ::acs {}
 #
 # package_id -> package_key
 #
@@ -1164,7 +1170,9 @@ ad_proc -public apm_version_get {
 ad_proc -public apm_package_key_from_id {package_id} {
     @return The package key of the instance.
 } {
-    return [util_memoize "apm_package_key_from_id_mem $package_id"]
+    set key ::acs::apm_package_key_from_id($package_id)
+    if {[info exists $key]} {return [set $key]}
+    set $key [apm_package_key_from_id_mem $package_id]
 }
 
 ad_proc -private apm_package_key_from_id_mem {package_id} {
@@ -1202,7 +1210,10 @@ ad_proc -public apm_package_id_from_key {package_key} {
     @return The package id of the instance of the package.
     0 if no instance exists, error if several instances exist.
 } {
-    return [util_memoize "apm_package_id_from_key_mem $package_key"]
+    set var ::apm::package_id_from_key($package_key)
+    if {[info exists $var]} {return [set $var]}
+    set $var [util_memoize "apm_package_id_from_key_mem $package_key"]
+    #set $var [ns_cache_eval ns:memoize apm_package_id_from_key_$package_key [list apm_package_id_from_key_mem $package_key]]
 }
 
 ad_proc -private apm_package_id_from_key_mem {package_key} {
@@ -1364,7 +1375,7 @@ ad_proc -private apm_post_instantiation_tcl_proc_from_key { package_key } {
     set procedure_name [string tolower "[string trim $package_key]_post_instantiation"]
     # Change all "-" to "_" to mimic our tcl standards
     regsub -all {\-} $procedure_name "_" procedure_name
-    if { [empty_string_p [info procs ::$procedure_name]] } {
+    if { [info commands ::$procedure_name] eq "" } {
 	# No such procedure exists... 
 	return ""
     }
@@ -1674,7 +1685,7 @@ ad_proc -private apm_callback_has_valid_args {
     @author Peter Marklund
 } {
 
-    if { [empty_string_p [info procs ::${proc_name}]] } {
+    if { [info commands ::$proc_name] eq "" } {
         return 0
     }
 
@@ -1685,7 +1696,7 @@ ad_proc -private apm_callback_has_valid_args {
 
     if { $test_arg_list eq "" } {
         # The callback proc should take no args
-        return [empty_string_p [info args ::${proc_name}]]
+        return [expr {[info args ::${proc_name}] eq ""}]
     }
 
     # The callback proc should have required arg switches. Check
