@@ -5,7 +5,7 @@ ad_library {
 
     @author Many others at ArsDigita and in the OpenACS community.
     @creation-date 2 April 1998
-    @cvs-id $Id: defs-procs.tcl,v 1.60 2010/03/25 01:02:16 donb Exp $
+    @cvs-id $Id: defs-procs.tcl,v 1.62 2013/04/08 15:50:25 gustafn Exp $
 }
 
 ad_proc -public ad_acs_version_no_cache {} {
@@ -299,7 +299,7 @@ ad_proc -deprecated ad_footer {
     } else {
 	set curriculum_bar ""
     }
-    if { [llength [info procs ds_link]] == 1 } {
+    if { [info commands ds_link] ne "" } {
 	set ds_link [ds_link]
     } else {
 	set ds_link ""
@@ -352,7 +352,7 @@ ad_proc -deprecated ad_admin_footer {} {
 
     @see  Documentation on the site master template for the proper way to standardize page footers
 } {
-    if { [llength [info procs ds_link]] == 1 } {
+    if { [info commands ds_link] ne "" } {
 	set ds_link [ds_link]
     } else {
 	set ds_link ""
@@ -665,18 +665,15 @@ ad_proc -public ad_parameter_from_file {
     @param name The name of the parameter.
     @return The parameter of the object or if it doesn't exist, the default.
 } {
-    set ns_param ""
 
     # The below is really a hack because none of the calls to ad_parameter in the system
     # actually call 'ad_parameter param_name acs-kernel'.
 
     if { $package_key eq "" || $package_key eq "acs-kernel"} {
-	set ns_param [ns_config "ns/server/[ns_info server]/acs" $name]
-    } else {
-	set ns_param [ns_config "ns/server/[ns_info server]/acs/$package_key" $name]
+	return [ns_config "ns/server/[ns_info server]/acs" $name]
     }
 
-    return $ns_param
+    return [ns_config "ns/server/[ns_info server]/acs/$package_key" $name]
 }
 
 
@@ -688,7 +685,7 @@ ad_proc -private ad_parameter_cache {
     parameter_name
 } {
     
-    Manages the cache for ad_paremeter.
+    Manages the cache for ad_parameter.
     @param -set Use this flag to indicate a value to set in the cache.
     @param -delete Delete the value from the cache
     @param -global If true, global param, false, instance param
