@@ -1,7 +1,7 @@
 ad_library {
     Provides procedures to spit out the navigational parts of the site.
 
-    @cvs-id $Id: navigation-procs.tcl,v 1.29 2010/01/19 23:53:59 torbenb Exp $
+    @cvs-id $Id: navigation-procs.tcl,v 1.30 2013/04/12 16:12:56 gustafn Exp $
     @author philg@mit.edu
     @creation-date 11/5/98 (adapted originally from the Cognet server)     
 }
@@ -410,7 +410,7 @@ proc ad_menu_header {{section ""} {uplink ""}} {
 
     # if it is an excluded directory, just return
     set url_stub [ad_conn url]
-    set full_filename "[ns_info pageroot]$url_stub"
+    set full_filename "$::acs::pageroot$url_stub"
    
 
     foreach naked_pattern [ad_naked_html_patterns] {
@@ -614,7 +614,7 @@ proc ad_menu_footer {{section ""}} {
    
     # if it is an excluded directory, just return
     set url_stub [ad_conn url]
-    set full_filename "[ns_info pageroot]$url_stub"
+    set full_filename "$::acs::pageroot$url_stub"
    
     foreach naked_pattern [ad_naked_html_patterns] {
 	if { [string match $naked_pattern $url_stub] } {
