@@ -4,7 +4,7 @@ ad_library {
 
     @creation-date 30 May 2000
     @author Jon Salz [jsalz@arsdigita.com]
-    @cvs-id $Id: request-processor-init.tcl,v 1.14 2009/02/12 15:38:41 jeffd Exp $
+    @cvs-id $Id: request-processor-init.tcl,v 1.15 2013/04/08 15:50:25 gustafn Exp $
 }
 
 # These procedures are dynamically defined at startup to alleviate
@@ -24,6 +24,41 @@ if { [parameter::get -package_id [ad_acs_kernel_id] -parameter PerformanceModeP
   }
 }
 
+if { [parameter::get -package_id [ad_acs_kernel_id] -parameter DebugP -default 0] ||
+     [parameter::get -package_id [ad_acs_kernel_id] -parameter LogDebugP -default 0]
+ } { 
+
+    ad_proc -private rp_debug { { -debug f } { -ns_log_level notice } string } {
+
+	Logs a debugging message, including a high-resolution (millisecond)
+	timestamp. 
+	
+    } {
+	if { [parameter::get -package_id [ad_acs_kernel_id] -parameter DebugP -default 0] } { 
+	    set clicks [clock clicks -milliseconds]
+	    ds_add rp [list debug $string $clicks $clicks]
+	}
+	if { [parameter::get -package_id [ad_acs_kernel_id] -parameter LogDebugP -default 0]
+	     || $debug eq "t" 
+	     || $debug eq "1"
+	 } {
+	    if { [info exists ::ad_conn(start_clicks)] } {
+		set timing " ([expr {([clock clicks -milliseconds] - $::ad_conn(start_clicks))}] ms)"
+	    } else {
+		set timing ""
+	    }
+	    ns_log $ns_log_level "RP$timing: $string"
+	}
+    }
+} else {
+    ad_proc -private rp_debug { { -debug f } { -ns_log_level notice } string } {
+	dummy placeholder
+    } {
+	return
+    }
+}
+
+
 # JCD this belongs in acs-permission-init.tcl but I did not want to duplicate [ad_acs_kernel_id]
 # Nuke the existing definition. and create one with the parameter set
 
