@@ -5,7 +5,7 @@ ad_library {
 
     @author Jon Salz (jsalz@arsdigita.com)
     @creation-date 15 May 2000
-    @cvs-id $Id: request-processor-procs.tcl,v 1.104 2011/02/16 19:03:01 daveb Exp $
+    @cvs-id $Id: request-processor-procs.tcl,v 1.113.2.1 2013/08/27 11:01:49 gustafn Exp $
 }
 
 #####
@@ -92,7 +92,7 @@ ad_proc rp_getform {} {
     
 } {
     # The form may not exist, if there's nothing in it
-    if { ![empty_string_p [ns_getform]] } {
+    if { [ns_getform] ne "" } {
         # It's there
         return [ns_getform]
     } {
@@ -495,16 +495,19 @@ ad_proc -private rp_resources_filter { why } {
 
 } {
     set path "[acs_package_root_dir [lindex [ns_conn urlv] 1]]/www/resources/[join [lrange [ns_conn urlv] 2 end] /]"
-    if { ![file isfile $path] } {
-        set path "[acs_root_dir]/www/resources/[join [lrange [ns_conn urlv] 1 end] /]"
-    }
     if { [file isfile $path] } {
         ns_returnfile 200 [ns_guesstype $path] $path
         return filter_return
-    } else {
-        ns_log Error "rp_sources_filter: file \"$path\" does not exists trying to serve as a normal request"
-        return filter_ok
     }
+
+    set path "[acs_root_dir]/www/resources/[join [lrange [ns_conn urlv] 1 end] /]"
+    if { [file isfile $path] } {
+        ns_returnfile 200 [ns_guesstype $path] $path
+        return filter_return
+    } 
+
+    ns_log Error "rp_sources_filter: file \"$path\" does not exists trying to serve as a normal request"
+    return filter_ok
 }
 
 ad_proc -private rp_filter { why } {
@@ -522,7 +525,15 @@ ad_proc -private rp_filter { why } {
     #####
 
     ad_conn -reset
-    ad_conn -set request [nsv_incr rp_properties request_count]
+    if {[ns_info name] eq "NaviServer"} {
+	# ns_conn id the internal counter by aolserver 4.5 and
+	# NaviServer. The semantics of the counter were different in
+	# Aolserver 4.0, when we require at least AolServer 4.5 the
+	# server test could go away.
+	ad_conn -set request [ns_conn id]
+    } else {
+	ad_conn -set request [nsv_incr rp_properties request_count]
+    }
     ad_conn -set user_id 0
     ad_conn -set start_clicks [clock clicks -milliseconds]
 
@@ -533,11 +544,12 @@ ad_proc -private rp_filter { why } {
     # -------------------------------------------------------------------------
     # 1. determine the root of the host and the requested URL
     set root [root_of_host [ad_host]]
-    set url [ad_conn url]
+    set ad_conn_url [ad_conn url]
+
     # 2. handle special case: if the root is a prefix of the URL, 
     #                         remove this prefix from the URL, and redirect.
     if { $root ne "" } {
-        if { [regexp "^${root}(.*)$" $url match url] } {
+        if { [regexp "^${root}(.*)$" $ad_conn_url match url] } {
 
             if { [regexp {^GET [^\?]*\?(.*) HTTP} [ns_conn request] match vars] } {
                 append url ?$vars
@@ -545,17 +557,18 @@ ad_proc -private rp_filter { why } {
             if { [security::secure_conn_p] } {
                 # it's a secure connection.
                 ad_returnredirect \
-                    -allow_complete_url https://[ad_host][ad_port]$url
+                    -allow_complete_url https://[ad_host][ad_port]$ad_conn_url
                 return "filter_return"
             } else {
                 ad_returnredirect \
-                    -allow_complete_url http://[ad_host][ad_port]$url
+                    -allow_complete_url http://[ad_host][ad_port]$ad_conn_url
                 return "filter_return"
             }
         }
         # Normal case: Prepend the root to the URL.
         # 3. set the intended URL
-        ad_conn -set url ${root}${url}
+        ad_conn -set url ${root}${ad_conn_url}
+	set ad_conn_url [ad_conn url]
 
         # 4. set urlv and urlc for consistency
         set urlv [lrange [split $root /] 1 end]
@@ -578,19 +591,16 @@ ad_proc -private rp_filter { why } {
     set user_agent [ns_set iget $headers User-Agent]
     ns_log Debug "user agent is $user_agent" 
 
-    set match_seeker [regexp ".*YahooSeeker.*" $user_agent]
-    set match_slurp  [regexp ".*Yahoo! Slurp.*" $user_agent]
-    if {$match_seeker == 1 || $match_slurp == 1} {
+    if {[string match "*YahooSeeker*" $user_agent] 
+	|| [string match ".*Yahoo! Slurp.*" $user_agent]} {
         ns_log Notice "nasty spider $user_agent"
         ns_returnredirect "http://www.yahoo.com"
         return "filter_return"
     }
-
     ## BLOCK NASTY YAHOO FINISH
 
-    set acs_kernel_id [util_memoize ad_acs_kernel_id]
     if { $root eq "" 
-         && [parameter::get -package_id $acs_kernel_id -parameter ForceHostP -default 0] } { 
+         && [parameter::get -package_id [ad_acs_kernel_id] -parameter ForceHostP -default 0] } { 
         set host_header [ns_set iget [ns_conn headers] "Host"]
         regexp {^([^:]*)} $host_header "" host_no_port
         regexp {^https?://([^:]+)} [ns_conn location] "" desired_host_no_port
@@ -614,14 +624,14 @@ ad_proc -private rp_filter { why } {
         ad_conn -set urlc [expr {[ad_conn urlc] - 1}]
         ad_conn -set urlv [lrange [ad_conn urlv] 0 [expr {[llength [ad_conn urlv]] - 2}] ]
     }
-
     rp_debug -ns_log_level debug -debug t "rp_filter: setting up request: [ns_conn method] [ns_conn url] [ns_conn query]"
 
-    if { [catch { array set node [site_node::get -url [ad_conn url]] } errmsg] } {
+    if { [catch { array set node [site_node::get -url $ad_conn_url] } errmsg] } {
         # log and do nothing
         rp_debug "error within rp_filter [ns_conn method] [ns_conn url] [ns_conn query].  $errmsg"
     } else {
-        if {$node(url) eq "[ad_conn url]/"} {
+
+        if {$node(url) eq "$ad_conn_url/"} {
             ad_returnredirect $node(url)
             rp_debug "rp_filter: returnredirect $node(url)"
             rp_debug "rp_filter: return filter_return"
@@ -637,7 +647,7 @@ ad_proc -private rp_filter { why } {
         ad_conn -set package_key $node(package_key)
         ad_conn -set package_url $node(url)
         ad_conn -set instance_name $node(instance_name)
-        ad_conn -set extra_url [string range [ad_conn url] [string length $node(url)] end]
+        ad_conn -set extra_url [string range $ad_conn_url [string length $node(url)] end]
     }
 
     #####
@@ -651,11 +661,9 @@ ad_proc -private rp_filter { why } {
       # We wrap this in a catch, because we don't want an error here to 
       # cause the request to fail.
       if { [catch { apm_load_any_changed_libraries } error] } {
-        global errorInfo
-        ns_log Error "rp_filter: error apm_load_any_changed_libraries: $errorInfo"
+        ns_log Error "rp_filter: error apm_load_any_changed_libraries: $::errorInfo"
       }
     }
-
     #####
     #
     # Read in and/or generate security cookies.
@@ -672,9 +680,10 @@ ad_proc -private rp_filter { why } {
 
     # Set locale and language of the request. We need ad_conn user_id to be set at this point
     if { [catch {
-        ad_conn -set locale [lang::conn::locale]
-        ad_conn -set language [lang::conn::language]
-        ad_conn -set charset [lang::util::charset_for_locale [ad_conn locale]] 
+	set locale [lang::conn::locale -package_id [ad_conn package_id]]
+        ad_conn -set locale $locale
+        ad_conn -set language [lang::conn::language -locale $locale]
+        ad_conn -set charset [lang::util::charset_for_locale $locale] 
     }] } {
         # acs-lang doesn't seem to be installed. Even though it must be installed now,
         # the problem is that if it isn't, everything breaks. So we wrap it in
@@ -686,6 +695,12 @@ ad_proc -private rp_filter { why } {
         ad_conn -set charset ""
     }
 
+    if {[ns_info name] eq "NaviServer"}  {
+	# provide context information for background writer
+	set requestor [expr {$::ad_conn(user_id) == 0 ? [ad_conn peeraddr] : $::ad_conn(user_id)}]
+	catch {ns_conn clientdata [list $requestor [ns_conn url]]}
+    }
+    
     # Who's online
     whos_online::user_requested_page [ad_conn untrusted_user_id]
 
@@ -694,8 +709,7 @@ ad_proc -private rp_filter { why } {
     # Make sure the user is authorized to make this request. 
     #
     #####
-
-    if { ![empty_string_p [ad_conn object_id]] } {
+    if { [ad_conn object_id] ne "" } {
       ad_try {
         switch -glob -- [ad_conn extra_url] {
             admin/* {
@@ -712,40 +726,16 @@ ad_proc -private rp_filter { why } {
             }
         }
       } ad_script_abort val {
-        rp_finish_serving_page
-        rp_debug "rp_filter: return filter_return"
-        return "filter_return"
+          rp_finish_serving_page
+          rp_debug "rp_filter: return filter_return"
+          return "filter_return"
       }
     }
+
     rp_debug "rp_filter: return filter_ok"
     return "filter_ok"
 }
 
-ad_proc -private rp_debug { { -debug f } { -ns_log_level notice } string } {
-
-    Logs a debugging message, including a high-resolution (millisecond)
-    timestamp. 
-
-} {
-    if { [parameter::get -package_id [ad_acs_kernel_id] -parameter DebugP -default 0] } { 
-        global ad_conn
-        set clicks [clock clicks -milliseconds]
-        ds_add rp [list debug $string $clicks $clicks]
-    }
-    if { [parameter::get -package_id [ad_acs_kernel_id] -parameter LogDebugP -default 0]
-         || $debug eq "t" 
-         || $debug eq "1"
-     } {
-        global ad_conn
-        if { [info exists ad_conn(start_clicks)] } {
-            set timing " ([expr {([clock clicks -milliseconds] - $ad_conn(start_clicks))}] ms)"
-        } else {
-            set timing ""
-        }
-        ns_log $ns_log_level "RP$timing: $string"
-    }
-}
-
 ad_proc rp_report_error {
     -message
 } {
@@ -778,8 +768,12 @@ ad_proc rp_report_error {
     #Serve the stacktrace
     set params [list [list stacktrace $message] [list user_id $user_id] [list error_file $error_file] [list prev_url $prev_url] [list feedback_id $feedback_id] [list error_url $error_url] [list bug_package_id $bug_package_id] [list vars_to_export $vars_to_export]]
     
-    if {![parameter::get -package_id [ad_acs_kernel_id] -parameter RestrictErrorsToAdminsP -default 0] || \
-            [permission::permission_p -object_id [ad_conn package_id] -privilege admin] } {
+    set error_message $message
+
+    if {[parameter::get -package_id [ad_acs_kernel_id] -parameter RestrictErrorsToAdminsP -default 0] && \
+            ![permission::permission_p -object_id [ad_conn package_id] -privilege admin] } {
+        set message {}
+        set params [lreplace $params 0 0 [list stacktrace $message]]    
     }
     
     with_catch errmsg {
@@ -788,7 +782,7 @@ ad_proc rp_report_error {
         # An error occurred during rendering of the error page
         global errorInfo
         ns_log Error "rp_report_error: Error rendering error page (!)\n$errorInfo"
-        set rendered_page "</table></table></table></h1></b></i><blockquote><pre>[ns_quotehtml $message]</pre></blockquote>[ad_footer]"
+        set rendered_page "</table></table></table></h1></b></i><blockquote><pre>[ns_quotehtml $error_message]</pre></blockquote>[ad_footer]"
     }
 
     ns_return 500 text/html $rendered_page
@@ -796,7 +790,7 @@ ad_proc rp_report_error {
     set headers [ns_conn headers]
     ns_log Error "[ns_conn method] http://[ns_set iget $headers host][ns_conn url]?[ns_conn query]
 referred by \"[ns_set iget $headers referer]\"
-$message"
+$error_message"
 
 }
 
@@ -841,6 +835,17 @@ ad_proc -private rp_handler {} {
       ad_returnredirect [ns_conn url]
       return
   }
+  if {$ad_conn(extra_url) ne "" && ![string match *$ad_conn(extra_url) [ns_conn url]]} {
+    # On internal redirects, the current extra_url might be from a
+    # previous request, which might have lead to a not-found error
+    # pointing to a new url. This can lead to an hard-to find loop
+    # which ends with a "recursion depth exceeded". Therefore, we
+    # refetch the url in case, in case, we have already extra_url 
+    # set to an incompatible value
+    #
+    array set node [site_node::get -url [ad_conn url]]
+    ad_conn -set extra_url [string range [ad_conn url] [string length $node(url)] end]
+  }
 
   # JCD: keep track of rp_handler call count to prevent dev support from recording 
   # information twice when for example we get a 404 internal redirect. We should probably 
@@ -864,7 +869,7 @@ ad_proc -private rp_handler {} {
       rp_debug -debug t "error in rp_handler: $errmsg"
     }
 
-    set resolve_values [concat [ns_info pageroot][string trimright [ad_conn package_url] /] \
+    set resolve_values [concat $::acs::pageroot[string trimright [ad_conn package_url] /] \
                                [apm_package_url_resolution [ad_conn package_key]]]
 
     foreach resolve_value $resolve_values {
@@ -1019,7 +1024,7 @@ ad_proc -private rp_serve_abstract_file {
 
     ad_conn -set file [rp_concrete_file -extension_pattern $extension_pattern $path]
     
-    if { [empty_string_p [ad_conn file]] } {
+    if { [ad_conn file] eq "" } {
       
       if { [file isdirectory $path] && !$noredirect_p } {
         # Directory name with no trailing slash. Redirect to the same
@@ -1424,8 +1429,7 @@ ad_proc -private ad_http_cache_control { } {
         return
     }
 
-    global ad_conn
-    if { [info exists ad_conn(no_http_cache_control_p)] && $ad_conn(no_http_cache_control_p) } {
+    if { [info exists ::ad_conn(no_http_cache_control_p)] && $::ad_conn(no_http_cache_control_p) } {
         return
     }
 
@@ -1435,13 +1439,13 @@ ad_proc -private ad_http_cache_control { } {
     # don't touch anything. 
     set modify_p 1
 
-    if { ([ns_set ifind $headers  "cache-control"] > -1 ||
-         [ns_set ifind $headers  "expires"] > -1) } {
+    if { [ns_set ifind $headers "cache-control"] > -1 ||
+         [ns_set ifind $headers "expires"] > -1 } {
         set modify_p 0
     } else {
         for { set i 0 } { $i < [ns_set size $headers] } { incr i } {
-            if { [string tolower [ns_set key $headers $i]] == "pragma" &&
-                 [string tolower [ns_set value $headers $i]] == "no-cache" } {
+            if { [string tolower [ns_set key $headers $i]] eq "pragma" &&
+                 [string tolower [ns_set value $headers $i]] eq "no-cache" } {
                 set modify_p 0
                 break
             }
@@ -1493,11 +1497,19 @@ ad_proc ad_port {} {
     }
 }
 
+namespace eval ::acs {}
+
 ad_proc root_of_host {host} {
     Maps a hostname to the corresponding sub-directory.
 } {
+    set key ::acs::root_of_host($host)
+    if {[info exists $key]} {return [set $key]}
+    set $key [root_of_host1 $key]
+}
+
+proc root_of_host1 {host} {
     # The main hostname is mounted at /.
-    if { [string equal $host [ns_config ns/server/[ns_info server]/module/nssock Hostname]] } {
+    if { $host eq [ns_config ns/server/[ns_info server]/module/nssock Hostname] } {
         return ""
     }
     # Other hostnames map to subsites.
@@ -1505,7 +1517,7 @@ ad_proc root_of_host {host} {
 
     if {$node_id eq ""} {
         set host [regsub "www\." $host ""]
-        set node_id [rp_lookup_node_from_host $host]
+	set node_id [util_memoize [list rp_lookup_node_from_host $host]]
     }
 
     if { $node_id ne "" } {
@@ -1535,20 +1547,24 @@ ad_proc -public request_denied_filter { why } {
 }
 
 
+
 if {[ns_info name] eq "NaviServer"} {
   # this is written for NaviServer 4.99.1 or newer
   foreach filter {rp_filter rp_resources_filter request_denied_filter} {
-    if {[info command ::${filter}_aolserver] eq ""} {
-      rename $filter ${filter}_aolserver
-    }
-    proc $filter {why} [list ${filter}_aolserver \$why ]
+    set cmd ${filter}_aolserver
+    if {[info command $cmd] ne ""} {rename $cmd ""}
+    rename $filter $cmd
+    proc $filter {why} "$cmd \$why" 
   }
 
-  if {[info command rp_invoke_filter_conn] eq ""} {
-    rename rp_invoke_filter rp_invoke_filter_conn
-    rename rp_invoke_proc   rp_invoke_proc_conn
-  }
-  proc   rp_invoke_filter { why filter_info} { rp_invoke_filter_conn _ $filter_info $why}
-  proc   rp_invoke_proc   { argv }            { rp_invoke_proc_conn _ $argv }
-
+  set cmd rp_invoke_filter_conn
+  if {[info command $cmd] ne ""} {rename $cmd ""}
+  rename rp_invoke_filter $cmd
+  proc   rp_invoke_filter { why filter_info} "$cmd _ \$filter_info \$why"
+  
+  set cmd rp_invoke_proc_conn
+  if {[info command $cmd] ne ""} {rename $cmd ""}
+  rename rp_invoke_proc   $cmd
+  proc   rp_invoke_proc   { argv } "$cmd _ \$argv"
 }
+
