@@ -7,7 +7,7 @@ ad_library {
     @author Jon Salz (jsalz@arsdigita.com)
     @author Richard Li (richardl@arsdigita.com)
     @author Archit Shah (ashah@arsdigita.com)
-    @cvs-id $Id: security-procs.tcl,v 1.72 2011/04/19 00:08:01 daveb Exp $
+    @cvs-id $Id: security-procs.tcl,v 1.74.2.1 2013/08/16 18:57:26 gustafn Exp $
 }
 
 namespace eval security {}
@@ -98,23 +98,20 @@ ad_proc -private sec_handler {} {
 	# The session cookie already exists and is valid.
 	set cookie_data [split [lindex $cookie_list 0] {,}]
 	set session_last_renew_time [lindex $cookie_data 3]
-    if {![string is integer -strict $session_last_renew_time]} {
-        # This only happens if the session cookie is old style
-        # previous to openacs 5.7 and does not have session review time
-        # embedded.
-        # Assume cookie expired and force login handler
-        set session_last_renew_time 0
-    }
-    
-    set session_expr [expr {$session_last_renew_time + [sec_session_timeout]}]
-    
-    if {$session_expr < [ns_time]} {
-        sec_login_handler
-    }
-               
-	set session_id [lindex $cookie_data 0]
-	set untrusted_user_id [lindex $cookie_data 1]
-	set login_level [lindex $cookie_data 2]
+	if {![string is integer -strict $session_last_renew_time]} {
+	    # This only happens if the session cookie is old style
+	    # previous to openacs 5.7 and does not have session review time
+	    # embedded.
+	    # Assume cookie expired and force login handler
+	    set session_last_renew_time 0
+	}
+
+	set session_expr [expr {$session_last_renew_time + [sec_session_timeout]}]
+	if {$session_expr < [ns_time]} {
+	    sec_login_handler
+	}
+	
+	lassign $cookie_data session_id untrusted_user_id login_level
         set user_id 0
         set account_status closed
         
@@ -211,12 +208,7 @@ ad_proc -private sec_login_handler {} {
     
     # check for permanent login cookie
     catch {
-	set login_list [sec_login_read_cookie]
-        
-        set untrusted_user_id [lindex $login_list 0]
-        set login_expr [lindex $login_list 1]
-        set auth_token [lindex $login_list 2]
-        
+        lassign [sec_login_read_cookie] untrusted_user_id login_expr auth_token
         set auth_level expired
         
         # Check authentication cookie
@@ -510,7 +502,7 @@ ad_proc -private sec_generate_session_id_cookie {} {
     set discard t
     set max_age [sec_session_timeout]
     catch { 
-	    set login_list [sec_login_read_cookie]
+        set login_list [sec_login_read_cookie]
       	if {[lindex $login_list end] == 1} {
 	        set discard f
             set max_age inf
@@ -868,12 +860,8 @@ ad_proc -public ad_verify_signature {
     @param secret specifies an external secret to use instead of the
     one provided by the ACS signature mechanism.
 } {
-    set token_id [lindex $signature 0]
-    set expire_time [lindex $signature 1]
-    set hash [lindex $signature 2]
-
+    lassign $signature token_id expire_time hash
     return [__ad_verify_signature $value $token_id $secret $expire_time $hash]
-
 }
 
 ad_proc -public ad_verify_signature_with_expr {
@@ -887,10 +875,7 @@ ad_proc -public ad_verify_signature_with_expr {
     @param secret specifies an external secret to use instead of the
     one provided by the ACS signature mechanism.
 } {
-    set token_id [lindex $signature 0]
-    set expire_time [lindex $signature 1]
-    set hash [lindex $signature 2]
-
+    lassign $signature token_id expire_time hash
     if { [__ad_verify_signature $value $token_id $secret $expire_time $hash] } {
 	return $expire_time
     } else {
@@ -917,6 +902,7 @@ ad_proc -private __ad_verify_signature {
 	    return 0
 	}
 	set secret_token [sec_get_token $token_id]
+
     } else {
 	set secret_token $secret
     }
@@ -925,7 +911,6 @@ ad_proc -private __ad_verify_signature {
     ns_log Debug "__ad_verify_signature: Expire_Time is $expire_time (compare to [ns_time]), hash is $hash"
 
     # validate cookie: verify hash and expire_time
-
     set computed_hash [ns_sha1 "$value$token_id$expire_time$secret_token"]
 
     # Need to verify both hash and expiration
@@ -977,19 +962,13 @@ ad_proc -public ad_get_signed_cookie {
 
 } {
 
-    if { $include_set_cookies eq "t" } {
-	set cookie_value [ns_urldecode [ad_get_cookie $name]]
-    } else {
-	set cookie_value [ns_urldecode [ad_get_cookie -include_set_cookies f $name]]
-    }
+    set cookie_value [ns_urldecode [ad_get_cookie -include_set_cookies $include_set_cookies $name]]
 
     if { $cookie_value eq "" } {
 	error "Cookie does not exist."
     }
 
-    set value [lindex $cookie_value 0]
-    set signature [lindex $cookie_value 1]
-
+    lassign $cookie_value value signature
     ns_log Debug "ad_get_signed_cookie: Got signed cookie $name with value $value, signature $signature."
 
     if { [ad_verify_signature $value $signature] } {
@@ -1015,19 +994,13 @@ ad_proc -public ad_get_signed_cookie_with_expr {
 
 } {
 
-    if { $include_set_cookies eq "t" } {
-	set cookie_value [ns_urldecode [ad_get_cookie $name]]
-    } else {
-	set cookie_value [ns_urldecode [ad_get_cookie -include_set_cookies f $name]]
-    }
+    set cookie_value [ns_urldecode [ad_get_cookie -include_set_cookies $include_set_cookies $name]]
 
     if { $cookie_value eq "" } {
 	error "Cookie does not exist."
     }
 
-    set value [lindex $cookie_value 0]
-    set signature [lindex $cookie_value 1]
-
+    lassign $cookie_value value signature
     set expr_time [ad_verify_signature_with_expr $value $signature]
 
     ns_log Debug "Security: Done calling get_cookie $cookie_value for $name; received $expr_time expiration, getting $value and $signature."
@@ -1122,43 +1095,65 @@ ad_proc -private sec_get_token {
 
 } {
     
-    global tcl_secret_tokens
+    set key ::security::tcl_secret_tokens($token_id)
+    if { [info exists $key] } { return [set $key] } 
 
-    if { [info exists tcl_secret_tokens($token_id)] } {
-	return $tcl_secret_tokens($token_id)
-    } else {
-	set token [ns_cache eval secret_tokens $token_id {
-	    set token [db_string get_token {select token from secret_tokens
-                       	                 where token_id = :token_id} -default 0]
-	    db_release_unused_handles
-
-	    # Very important to throw the error here if $token == 0
-
-            if { $token == 0 } {
-	        error "Invalid token ID"
-	    }
-
-	    return $token
-	}]
-
-	set tcl_secret_tokens($token_id) $token
-	return $token
-	
+    if {[array size ::security::tcl_secret_tokens] == 0} {
+	populate_secret_tokens_thread_cache
+	if { [info exists $key] } { return [set $key] } 
     }
+    
+    #
+    # We might get token_ids from previous runs, so we have fetch these
+    # in case of a validation
+    #
+    set token [ns_cache eval secret_tokens $token_id {
+       set token [db_string get_token {select token from secret_tokens
+           where token_id = :token_id} -default 0]
+       db_release_unused_handles
+       
+       # Very important to throw the error here if $token == 0
+       
+       if { $token == 0 } {
+           error "Invalid token ID"
+       }
+       
+        return $token
+    }]
 
+    set $key $token
+    return $token
 }
 
 ad_proc -private sec_get_random_cached_token_id {} {
     
-    Randomly returns a token_id from the ns_cache.
+    Randomly returns a token_id from the token cache
 
 } {
- 
-    set list_of_names [ns_cache names secret_tokens]
-    set random_seed [ns_rand [llength $list_of_names]]
+    #set list_of_names [ns_cache names secret_tokens]
+    set list_of_names [array names ::security::tcl_secret_tokens]
+    if {[llength $list_of_names] == 0} {
+        populate_secret_tokens_thread_cache
+        set list_of_names [array names ::security::tcl_secret_tokens]
+    }
 
+    set random_seed [ns_rand [llength $list_of_names]]
     return [lindex $list_of_names $random_seed]
-    
+}
+
+ad_proc -private populate_secret_tokens_thread_cache {} {
+     
+    Copy secret_tokens cache to per-thread variables
+
+} {
+    set ids [ns_cache names secret_tokens]
+    if {[llength $ids] == 0} {
+       populate_secret_tokens_cache
+       set ids [ns_cache names secret_tokens]
+    }
+    foreach name $ids {
+       set ::security::tcl_secret_tokens($name) [ns_cache get secret_tokens $name]
+    }
 }
 
 ad_proc -private populate_secret_tokens_cache {} {
@@ -1297,8 +1292,7 @@ ad_proc -public ad_get_client_property {
     if { $property eq "" } {
 	return $default
     }
-    set value [lindex $property 0]
-    set secure_p [lindex $property 1]
+    lassign $property value secure_p
     
     if { $secure_p ne "f" && ![security::secure_conn_p] } {
 	return ""
@@ -1459,13 +1453,13 @@ ad_proc -public security::https_available_p {} {
 
     @author Peter Marklund
 } {
-    return [expr ![empty_string_p [get_https_port]]]
+    return [expr {[get_https_port] ne ""}]
 }
 
 ad_proc -public security::secure_conn_p {} { 
     Returns true if the connection [ad_conn] is secure (HTTPS), or false otherwise. 
 } {
-    return [string match "https:*" [util_current_location]]
+    return [string match "https:*" [ns_conn location]]
 }
 
 ad_proc -public security::RestrictLoginToSSLP {} {
@@ -1684,6 +1678,26 @@ ad_proc -private security::get_insecure_location {} {
     return $insecure_location
 }
 
+if {[ns_info name] ne "NaviServer"} {
+    #
+    # compatibility with NaviServer, which allows global and per-server
+    # defined drivers.
+    #
+    ad_proc -public ns_driversection {
+	{-driver "nssock"}
+	{-server ""}
+    } {
+	Return the section name in the config file containing configuration information about the 
+	network connection.
+	@param driver (e.g. nssock)
+	@param server symobolic server name 
+	@return name of section of the drive in the config file
+    } {
+	if {$server eq ""} {set server [ns_info server]}
+	return "ns/server/$server/module/$driver"
+    }
+}
+
 ad_proc -public security::locations {} {
     @return insecure location and secure location followed possibly by alternate insecure location(s)  as a list.
 
@@ -1740,15 +1754,18 @@ ad_proc -public security::locations {} {
     if {![regexp {(http://|https://)(.*?):(.*?)/?} [util_current_location] discard host_protocol host_name host_port]} {
         regexp {(http://|https://)(.*?)/?} [util_current_location] discard host_protocol host_name
     }
-    # let's give a warning if util_current_location returns host_name
+
+    set driver_section [ns_driversection -driver $driver]
+    
+    # Let's give a warning if util_current_location returns host_name
     # not same as from config.tcl, may help with proxy issues etc
-    set config_hostname [ns_config ns/server/[ns_info server]/module/$driver Hostname]
+    set config_hostname [ns_config $driver_section Hostname]
     if { $config_hostname ne $host_name } {
-        ns_log Warning "security::locations hostname '[ns_config ns/server/[ns_info server]/module/$driver Hostname]' from config.tcl does not match from util_current_location: $host_name"
+        ns_log Warning "security::locations hostname '[ns_config $driver_section Hostname]' from config.tcl does not match from util_current_location: $host_name"
     }
 
     # insecure locations
-    set insecure_port [ns_config -int "ns/server/[ns_info server]/module/$driver" port 80]
+    set insecure_port [ns_config -int $driver_section port 80]
 
     set insecure_location "http://${host_name}"
     set host_map_http_port ""
@@ -1764,10 +1781,14 @@ ad_proc -public security::locations {} {
         set secure_port [ns_config -int "ns/server/[ns_info server]/module/$sdriver/ssldriver/users" port 443]
     } elseif { $sdriver ne "" } {
         # get secure port for all other cases of nsssl, nsssle etc
-        set secure_port [ns_config -int "ns/server/[ns_info server]/module/$sdriver" port]
-        # checking nsopenssl 2.0 which has different names for the secure port etc, and deprecated with this version of OpenACS
+	set driver_section [ns_driversection -driver $sdriver]
+        set secure_port [ns_config -int $driver_section port]
+	
+        # checking nsopenssl 2.0 which has different names for 
+	# the secure port etc, and deprecated with this version of OpenACS
         if {$secure_port eq "" || $secure_port eq "443" } {
-            set secure_port [ns_config -int "ns/server/[ns_info server]/module/$sdriver" ServerPort 443]
+	    ns_log Notice "Using 'ServerPort' in $driver_section is deprecated"
+            set secure_port [ns_config -int $driver_section ServerPort 443]
         }
     } else {
         set secure_port ""
@@ -1786,7 +1807,9 @@ ad_proc -public security::locations {} {
         lappend locations $secure_location
     }
     # consider if we are behind a proxy and don't want to publish the proxy's backend port
-    set suppress_http_port [parameter::get -parameter SuppressHttpPort -package_id [apm_package_id_from_key acs-tcl] -default 0]
+    set suppress_http_port [parameter::get -parameter SuppressHttpPort \
+				-package_id [apm_package_id_from_key acs-tcl] \
+				-default 0]
     if { [info exists alt_insecure_location] && $suppress_http_port } {
         lappend locations $alt_insecure_location
     }
