@@ -4,7 +4,7 @@ ad_library {
     
     @author Lars Pind (lars@pinds.com)
     @creation-date 19 July 2000
-    @cvs-id $Id: text-html-procs.tcl,v 1.65 2010/03/11 11:20:48 gustafn Exp $
+    @cvs-id $Id: text-html-procs.tcl,v 1.65.6.2 2013/08/27 17:05:58 victorg Exp $
 }
 
 
@@ -789,7 +789,7 @@ ad_proc ad_html_security_check { html } {
                     }
             
                     if { [string tolower $attr_name] ne "style" } {
-                        if { [regexp {^\s*([^\s:]+):} $attr_value match protocol] } {
+                        if { [regexp {^\s*([^\s:]+):\/\/} $attr_value match protocol] } {
                             if { ![info exists allowed_protocol([string tolower $protocol])] && ![info exists allowed_protocol(*)] } {
                                 return "Your URLs can only use these protocols: [join $allowed_protocols_list ", "].
                 You have a '$protocol' protocol in there."
@@ -1000,7 +1000,7 @@ ad_proc -public ad_html_to_text {
                             }
                         } else {
                             if { [llength $href_stack] > 0 } {
-                                if { ![empty_string_p [lindex $href_stack end]] } {
+                                if { [lindex $href_stack end] ne "" } {
                                     ad_html_to_text_put_text output " [lindex $href_stack end]"
                                 }
                                 set href_stack [lreplace $href_stack end end]
