@@ -3,7 +3,7 @@
 # Copyright (C) 1999-2000 ArsDigita Corporation
 # Authors: Karl Goldstein    (karlg@arsdigita.com)
 #          
-# $Id: data-procs.tcl,v 1.16 2010/11/13 23:55:58 donb Exp $
+# $Id: data-procs.tcl,v 1.17 2012/12/08 17:50:20 gustafn Exp $
 
 # This is free software distributed under the terms of the GNU Public
 # License.  Full text of the license is available from the GNU Project:
@@ -434,10 +434,8 @@ ad_proc -public template::data::transform {
   @param type The data type to be transformed.
 } {
 
-  set proc_name [info procs ::template::data::transform::$type]
-
+  set proc_name [info commands ::template::data::transform::$type]
   if { $proc_name ne {} } {
-
     transform::$type $value_ref
   }
 }
