@@ -3,7 +3,7 @@ ad_library {
 
     @author Ola Hansson (ola@polyxena.net)
     @creation-date 2003-09-21
-    @cvs-id $Id: spellcheck-procs.tcl,v 1.19 2010/01/22 14:10:30 emmar Exp $
+    @cvs-id $Id: spellcheck-procs.tcl,v 1.21.2.1 2013/08/27 11:33:14 gustafn Exp $
 }
 
 namespace eval template {}
@@ -202,6 +202,10 @@ ad_proc -public template::util::spellcheck::get_element_formtext {
 
     set spellchecker_path [nsv_get spellchecker path]
 
+    #
+    # Force default language to en_US
+    #set ::env(LANG) en_US.UTF-8
+
     # the --lang switch only works with aspell and if it is not present
     # aspell's (or ispell's) default language will have to do.
     set lang_and_enc "--encoding=utf-8"
@@ -234,7 +238,7 @@ ad_proc -public template::util::spellcheck::get_element_formtext {
 	ad_script_abort
     }
 
-    ns_unlink $tmpfile
+    file delete $tmpfile
 
     if { $try == $max_retry } {
         return -code error "webspell: Tried to execute spellchecker $max_retry times but it did not work out. Sorry!"
@@ -350,7 +354,7 @@ ad_proc -public template::util::spellcheck::spellcheck_properties {
 } {
     upvar $element_ref element
     
-    if { [empty_string_p [set spellcheck_value [ns_queryget $element(id).spellcheck]]] } {
+    if { [set spellcheck_value [ns_queryget $element(id).spellcheck]] eq "" } {
 	
 	# The user hasn't been able to state whether (s)he wants spellchecking to be performed or not.
 	# That's either because spell-checking is disabled for this element, or we're not dealing with a submit.
@@ -360,7 +364,7 @@ ad_proc -public template::util::spellcheck::spellcheck_properties {
 
 	if { [string equal "display" $element(mode)] \
 		 || [info exists element(nospell)] \
-		 || [empty_string_p [nsv_get spellchecker path]] } {
+		 || [nsv_get spellchecker path] eq "" } {
 
 	    set spellcheck_p 0
 	} else {
