@@ -5,7 +5,7 @@
 #          Stanislav Freidin 	  (sfreidin@arsdigita.com)
 #          Christian Brechbuehler (chrisitan@arsdigita.com)
 
-# $Id: tag-procs.tcl,v 1.15 2007/01/10 21:22:12 gustafn Exp $
+# $Id: tag-procs.tcl,v 1.18 2013/03/30 17:53:58 gustafn Exp $
 
 # This is free software distributed under the terms of the GNU Public
 # License.  Full text of the license is available from the GNU Project:
@@ -86,7 +86,8 @@ ad_proc -public template_tag_if_concat_params { params } {
   # I'm not sure why we need to eval here at all, there ought to be another solution,
   # but it's not clear what the intention of below statement is.
 
-  set tokens [eval [concat list [join $tokens " "]]]
+  #set tokens [eval [concat list [join $tokens " "]]]
+  set tokens [join $tokens " "]
 
   return $tokens
 }
@@ -134,11 +135,11 @@ ad_proc -public template_tag_if_interp_expr {} {
       set next [expr {$i + 1}]
     }
     eq { 
-      append condition "\[string equal $arg1 \"[lindex $args $i]\"\]" 
+      append condition "$arg1 eq \"[lindex $args $i]\"" 
       set next [expr {$i + 1}]
     }
     ne { 
-      append condition "! \[string equal $arg1 \"[lindex $args $i]\"\]" 
+      append condition "$arg1 ne \"[lindex $args $i]\"" 
       set next [expr {$i + 1}]
     }
 
@@ -158,11 +159,11 @@ ad_proc -public template_tag_if_interp_expr {} {
     nil {
       if { [string first @ $arg1] == -1 } {
         # We're assuming this is a static string, not a variable
-        append condition "\[empty_string_p $arg1\]"
+        append condition "$arg1 eq {}"
       } else {
         # substitute array variables
-        if {! ( [regsub {^"@([a-zA-Z0-9_]+)\.([a-zA-Z0-9_.]+)@"$} $arg1 {\1(\2)} arg1]
-                || [regsub {^"@([a-zA-Z0-9_:]+)@"$} $arg1 {\1} arg1] ) } {
+        if {! ( [regsub {^"@([a-zA-Z0-9_]+)\.([a-zA-Z0-9_.]+)(;\w+)?@"$} $arg1 {\1(\2)} arg1]
+		|| [regsub {^"@([a-zA-Z0-9_:]+)(;\w+)?@"$} $arg1 {\1} arg1] ) } {
           error "IF tag nil test uses string not variable for $arg1"
         }
         append condition "\[template::util::is_nil $arg1\]"
