@@ -1,7 +1,7 @@
 ad_page_contract {
     @author Neophytos Demetriou <k2pts@cytanet.com.cy>
     @creation-date September 01, 2001
-    @cvs-id $Id: search.tcl,v 1.36 2010/02/04 21:06:42 daveb Exp $
+    @cvs-id $Id: search.tcl,v 1.37.2.1 2013/08/26 07:57:14 gustafn Exp $
 } {
     q:trim
     {t:trim ""}
@@ -39,7 +39,7 @@ if {[callback::impl_exists -impl $driver -callback search::driver_info]} {
     array set info [lindex [callback -impl $driver search::driver_info] 0]
 #    array set info [list package_key intermedia-driver version 1 automatic_and_queries_p 1  stopwords_p 1]
 } else {
-    array set info [acs_sc_call FtsEngineDriver info [list] $driver]
+    array set info [acs_sc::invoke -contract FtsEngineDriver -operation info -call_args [list] -impl $driver]
 }
 
 if { [array get info] eq "" } {
@@ -94,7 +94,9 @@ set params [list $q $offset $limit $user_id $df]
 if {$search_package_id eq "" && [parameter::get -package_id $package_id -parameter SubsiteSearchP -default 1]
     && [subsite::main_site_id] != [ad_conn subsite_id]} {
     # We are in a subsite and SubsiteSearchP is true
-    lappend params [concat [ad_conn subsite_id] [subsite::util::packages -node_id [ad_conn node_id]]]
+    set subsite_packages [concat [ad_conn subsite_id] [subsite::util::packages -node_id [ad_conn node_id]]]
+    lappend params $subsite_packages
+    set search_package_id $subsite_packages
 } else { 
   lappend params $search_package_id
 }
@@ -119,7 +121,7 @@ if {[callback::impl_exists -impl $driver -callback search::search]} {
 
     array set result [lindex [callback -impl $driver search::search -query $q -offset $offset -limit $limit -user_id $user_id -df $df -extra_args [list package_ids $search_package_id object_type $object_type]] 0]
 } else {
-    array set result [acs_sc_call FtsEngineDriver search $params $driver]
+    array set result [acs_sc::invoke -contract FtsEngineDriver -operation search -call_args $params -impl $driver]
 }
 set tend [clock clicks -milliseconds]
 
@@ -129,7 +131,7 @@ if { $t eq [_ search.Feeling_Lucky] && $result(count) > 0} {
     if {[callback::impl_exists -impl $object_type -callback search::url]} {
 	set url [callback -impl $object_type search::url -object_id $object_id]
     } else {
-	set url [acs_sc_call FtsContentProvider url [list $object_id] $object_type]
+	set url [acs_sc::invoke -contract FtsContentProvider -operation url -call_args [list $object_id] -impl $object_type]
     }
     ad_returnredirect $url
     ad_script_abort
@@ -172,16 +174,16 @@ for { set __i 0 } { $__i < [expr {$high - $low +1}] } { incr __i } {
             set url_one [lindex [callback -impl $object_type search::url -object_id $object_id] 0]
         } else {
             ns_log warning "SEARCH search/www/search.tcl callback::datasource::$object_type not found"
-            array set datasource [acs_sc_call FtsContentProvider datasource [list $object_id] $object_type]
-            set url_one [acs_sc_call FtsContentProvider url [list $object_id] $object_type]
+            array set datasource [acs_sc::invoke -contract FtsContentProvider -operation datasource -call_args [list $object_id] -impl $object_type]
+            set url_one [acs_sc::invoke -contract FtsContentProvider -operation url -call_args [list $object_id] -impl $object_type]
         }
         search::content_get txt $datasource(content) $datasource(mime) $datasource(storage_type) $object_id
         if {[callback::impl_exists -impl $driver -callback search::summary]} {
             set title_summary [lindex [callback -impl $driver search::summary -query $q -text $datasource(title)] 0]
             set txt_summary [lindex [callback -impl $driver search::summary -query $q -text $txt] 0]
         } else {
-            set title_summary [acs_sc_call FtsEngineDriver summary [list $q $datasource(title)] $driver]
-            set txt_summary [acs_sc_call FtsEngineDriver summary [list $q $txt] $driver]
+            set title_summary [acs_sc::invoke -contract FtsEngineDriver -operation summary -call_args [list $q $datasource(title)] -impl $driver]
+            set txt_summary [acs_sc::invoke -contract FtsEngineDriver -operation summary -call_args [list $q $txt] -impl $driver]
         }
     } errmsg]} {
         ns_log error "search.tcl object_id $object_id object_type $object_type error $errmsg"
