@@ -4,7 +4,7 @@ ad_library {
     @author Dave Bauer (dave@thedesignexperience.org)
     @creation-date 2004-06-05
     @arch-tag: 49a5102d-7c06-4245-8b8d-15a3b12a8cc5
-    @cvs-id $Id: tsearch2-driver-procs.tcl,v 1.28 2010/11/05 16:35:10 daveb Exp $
+    @cvs-id $Id: tsearch2-driver-procs.tcl,v 1.29.2.1 2013/08/28 23:08:36 michaels Exp $
 }
 
 namespace eval tsearch2 {}
@@ -84,13 +84,21 @@ ad_proc -public tsearch2::update_index {
     }
 }
 
+#ad_proc -callback search::search -impl tsearch2-driver {
+#    {-extra_args {}}
+#    query
+#    offset
+#    limit
+#    user_id
+#    df
+#} 
 ad_proc -callback search::search -impl tsearch2-driver {
     {-extra_args {}}
-    query
-    offset
-    limit
-    user_id
-    df
+    -query
+    -offset
+    -limit
+    -user_id
+    -df
 } {
     ftsenginedriver search operation implementation for tsearch2
 
@@ -257,6 +265,9 @@ ad_proc tsearch2::build_query { -query } {
         regsub -all {\(|\)} $query {} query
     }
 
+    # remove empty ()
+    regsub -all {\(\s*\)} $query {} query
+
     # remove or at beginning of query 
     regsub -nocase "^or " $query {} query
     # replace boolean words with boolean operators
